from typing import Any, Dict


_未提供 = object()

def 取值_必填(
    数据: Dict[str, Any],
    键: Any,
    默认值: Any = None,
    失败标记: Any = _未提供
) -> Any:
    """获取指定键的值；若键不存在，则返回默认值或指定失败标记。

    功能说明:
        - 这个函数用于获取指定键的值；若键不存在，则返回默认值或指定失败标记。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回约定好的兜底结果，避免程序因为异常中断。

    Args:
        数据 (dict): 用于取值的字典对象。
        键: 要读取的键，内部将转换为字符串。
        默认值: 当取值失败且未提供失败标记时返回的值，默认为 None。
        失败标记: 当取值失败时优先返回的专用标记。
        - 示例： "字段缺失"
        - 示例： False

    Returns:
        Any:
        - 成功：返回字典中对应键的值；
        - 失败：返回失败标记或默认值。"""
    try:
        if not isinstance(数据, dict):
            return 默认值 if 失败标记 is _未提供 else 失败标记

        键名 = str(键)
        if 键名 in 数据:
            return 数据[键名]

        return 默认值 if 失败标记 is _未提供 else 失败标记
    except Exception:
        return 默认值 if 失败标记 is _未提供 else 失败标记


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    键 = "名称"
    默认值 = "默认值"
    失败标记 = "缺失"
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    键 = "name"
    默认值 = "未找到"
    失败标记 = False
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键 = "不存在"
    默认值 = "空"
    失败标记 = "失败"
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键 = "名称"
    默认值 = "失败"
    失败标记 = "参数错误"
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    键 = "备注"
    默认值 = 0
    失败标记 = "未命中"
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    键 = "状态"
    默认值 = "未知状态"
    失败标记 = "字段缺失"
    print("结果:", 取值_必填(数据, 键, 默认值, 失败标记))
    print("数据:", 数据)



from __future__ import annotations

from typing import Any, List, Sequence, Union


_路径类型 = Union[str, Sequence[Any]]


def 删除键_路径(
    数据: Any,
    键路径: _路径类型,
    分隔符: str = ".",
    键转字符串: bool = True,
) -> bool:
    """根据路径删除嵌套字典或列表中的目标项。

    功能说明:
        - 这个函数用于根据路径删除嵌套字典或列表中的目标项。
        - 当你拿到的是多层结构的数据时，可以直接传入路径，不用自己一层一层往下找。
        - 它适合处理接口返回值、配置数据、表单结构这类多层字典场景。

    Args:
        数据: 通常为 dict 或 list 的嵌套结构。
        键路径: 路径字符串或路径序列。
            - 字符串示例： "a.b.0.c"
            - 列表示例： ["a", "b", 0, "c"]
        分隔符: 字符串路径的分隔符，默认 "."。
        键转字符串: 当走 dict 路径时，是否将键统一转为 str。默认 True。

    Returns:
        删除成功时返回 ``True``；删除失败时返回 ``False``。
    """
    try:
        if isinstance(键路径, str):
            if 键路径 == "":
                return False
            路径列表: List[Any] = 键路径.split(分隔符)
        elif isinstance(键路径, (list, tuple)):
            if len(键路径) == 0:
                return False
            路径列表 = list(键路径)
        else:
            return False

        if not isinstance(数据, (dict, list)):
            return False

        if len(路径列表) == 1:
            父级 = 数据
            末段 = 路径列表[0]
        else:
            父级 = 数据
            for 段 in 路径列表[:-1]:
                if isinstance(父级, dict):
                    键名 = str(段) if 键转字符串 else 段
                    if 键名 not in 父级:
                        return False
                    父级 = 父级[键名]
                    continue

                if isinstance(父级, (list, tuple)):
                    try:
                        目标索引 = 段 if isinstance(段, int) else int(str(段))
                    except Exception:
                        return False

                    if 目标索引 < 0 or 目标索引 >= len(父级):
                        return False

                    父级 = 父级[目标索引]
                    continue

                return False

            末段 = 路径列表[-1]

        if isinstance(父级, dict):
            键名 = str(末段) if 键转字符串 else 末段
            if 键名 not in 父级:
                return False
            del 父级[键名]
            return True

        if isinstance(父级, list):
            try:
                目标索引 = 末段 if isinstance(末段, int) else int(str(末段))
            except Exception:
                return False

            if 目标索引 < 0 or 目标索引 >= len(父级):
                return False

            del 父级[目标索引]
            return True

        return False
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"用户": {"信息": [{"城市": "上海", "年龄": 18}]}}
    print("结果:", 删除键_路径(数据, "用户.信息.0.城市"))
    print("数据:", 数据)

    print("\n===== 示例2：使用列表路径 =====")
    数据 = {"用户": {"信息": [{"城市": "北京", "年龄": 20}]}}
    print("结果:", 删除键_路径(数据, ["用户", "信息", 0, "年龄"]))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况-空路径 =====")
    数据 = {"用户": {"信息": [{"城市": "上海"}]}}
    print("结果:", 删除键_路径(数据, ""))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况-数据不是字典或列表 =====")
    数据 = []
    print("结果:", 删除键_路径(数据, "用户.信息.0.城市"))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况-路径不存在 =====")
    数据 = {"用户": {"信息": [{"城市": None, "标签": ""}]}}
    print("结果:", 删除键_路径(数据, "用户.信息.0.电话"))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-删除订单中的联系人 =====")
    数据 = {"订单": {"收货信息": [{"联系人": "张三", "电话": "123456"}]}}
    print("结果:", 删除键_路径(数据, "订单.收货信息.0.联系人"))
    print("数据:", 数据)



from typing import Any, Iterable, Tuple


def 保序去交集(元组数据: Tuple[Any, ...], 需要去除成员组: Iterable[Any]):
    """从元组中移除另一组成员，保持原顺序。

    功能说明:
        - 这个函数用于从元组中移除另一组成员，保持原顺序。
        - 它会在处理成员关系的同时，尽量保留原始元组中的先后顺序。
        - 适合既想做筛选或比对，又不希望把原来的顺序打乱的场景。

    Args:
        元组数据: 原始元组。
        需要去除成员组: 需要去除的成员序列。

    Returns:
        成功时返回处理后的新元组；失败时返回空元组 ``()``。
    """
    try:
        if not isinstance(元组数据, tuple):
            return ()

        去除列表 = tuple(需要去除成员组)
        if not 去除列表:
            return 元组数据

        return tuple(元素 for 元素 in 元组数据 if 元素 not in 去除列表)
    except Exception:
        return ()


if __name__ == "__main__":
    print("===== 示例1：基础去交集 =====")
    数据 = (1, 2, 3, 4, 5)
    print("结果:", 保序去交集(数据, (2, 4)))

    print("\n===== 示例2：去除成员不存在 =====")
    数据 = ("a", "b", "c")
    print("结果:", 保序去交集(数据, ("x", "y")))

    print("\n===== 示例3：去除列表为空 =====")
    数据 = ("a", "b", "c")
    print("结果:", 保序去交集(数据, ()))

    print("\n===== 示例4：存在重复成员 =====")
    数据 = ("a", "b", "a", "c", "b")
    print("结果:", 保序去交集(数据, ("a",)))

    print("\n===== 示例5：复杂对象去除 =====")
    数据 = ([1], {"x": 1}, [2], {"x": 1})
    print("结果:", 保序去交集(数据, ({"x": 1},)))

    print("\n===== 示例6：应用场景-从权限列表中移除禁用权限 =====")
    当前权限 = ("查看", "编辑", "导出", "管理员")
    禁用权限 = ("导出", "管理员")
    print("结果:", 保序去交集(当前权限, 禁用权限))






from typing import Any, Tuple


def 取首个重复成员(元组数据: Tuple[Any, ...]):
    """返回元组中首个被识别为重复的成员。

    功能说明:
        - 这个函数用于返回元组中首个被识别为重复的成员。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    说明:
        - 从左到右扫描，一旦某成员第二次出现，就返回该成员。

    Args:
        元组数据: 待统计的元组。

    Returns:
        找到时返回该成员；未找到或失败时返回 ``None``。
    """
    try:
        if not isinstance(元组数据, tuple):
            return None

        已见成员 = []
        for 元素 in 元组数据:
            if 元素 in 已见成员:
                return 元素
            已见成员.append(元素)
        return None
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础首个重复成员 =====")
    数据 = (1, 2, 3, 2, 4, 1)
    print("结果:", 取首个重复成员(数据))

    print("\n===== 示例2：重复成员出现在更后面 =====")
    数据 = ("a", "b", "c", "d", "b")
    print("结果:", 取首个重复成员(数据))

    print("\n===== 示例3：没有重复 =====")
    数据 = (1, 2, 3)
    print("结果:", 取首个重复成员(数据))

    print("\n===== 示例4：空元组 =====")
    数据 = ()
    print("结果:", 取首个重复成员(数据))

    print("\n===== 示例5：包含不可哈希成员 =====")
    数据 = ([1], [2], [1], [3])
    print("结果:", 取首个重复成员(数据))

    print("\n===== 示例6：应用场景-找出首个重复扫码结果 =====")
    扫码记录 = ("SN001", "SN002", "SN003", "SN002", "SN004")
    print("结果:", 取首个重复成员(扫码记录))






from typing import Any, Tuple


def 取重复成员列表(元组数据: Tuple[Any, ...]) -> Tuple[Any, ...]:
    """返回元组中的重复成员列表。

    功能说明:
        - 这个函数用于返回元组中的重复成员列表。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    说明:
        - 每种重复成员仅保留一次。
        - 返回顺序按其“首次被判定为重复”的先后顺序。

    Args:
        元组数据: 待统计的元组。

    Returns:
        成功时返回重复成员元组；失败时返回空元组 ``()``。
    """
    try:
        if not isinstance(元组数据, tuple):
            return ()

        已见成员 = []
        重复成员 = []
        for 元素 in 元组数据:
            if 元素 in 已见成员:
                if 元素 not in 重复成员:
                    重复成员.append(元素)
            else:
                已见成员.append(元素)
        return tuple(重复成员)
    except Exception:
        return ()


if __name__ == "__main__":
    print("===== 示例1：基础重复成员列表 =====")
    数据 = (1, 2, 1, 3, 2, 4)
    print("结果:", 取重复成员列表(数据))

    print("\n===== 示例2：全部唯一 =====")
    数据 = ("a", "b", "c")
    print("结果:", 取重复成员列表(数据))

    print("\n===== 示例3：同一成员多次重复只保留一次 =====")
    数据 = ("a", "a", "a", "b")
    print("结果:", 取重复成员列表(数据))

    print("\n===== 示例4：空元组 =====")
    数据 = ()
    print("结果:", 取重复成员列表(数据))

    print("\n===== 示例5：包含不可哈希成员 =====")
    数据 = ([1], [1], {"x": 1}, {"x": 1}, [2])
    print("结果:", 取重复成员列表(数据))

    print("\n===== 示例6：应用场景-找出重复的标签项 =====")
    标签列表 = ("已支付", "待发货", "已支付", "高优先级", "待发货")
    print("结果:", 取重复成员列表(标签列表))






from typing import Any, Dict

def 重命名键(
    数据: Dict[str, Any],
    旧键: Any,
    新键: Any
) -> bool:
    """将字典中的旧键重命名为新键。

    功能说明:
        - 这个函数用于将字典中的旧键重命名为新键。
        - 它主要返回 True 或 False，适合直接写在 if 判断里控制后续流程。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        数据 (dict): 需要处理的字典对象。
        旧键: 需要被重命名的键。
        新键: 新的键名。

    Returns:
        bool:
        True  - 重命名成功；
        False - 重命名失败。"""
    try:
        if not isinstance(数据, dict):
            return False

        旧键名 = str(旧键)
        新键名 = str(新键)

        if 旧键名 not in 数据:
            return False

        if 旧键名 == 新键名:
            return True

        数据[新键名] = 数据[旧键名]
        del 数据[旧键名]
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    旧键 = "名称"
    新键 = "用户名"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    旧键 = "name"
    新键 = "姓名"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    旧键 = "不存在"
    新键 = "名称"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    旧键 = "名称"
    新键 = "新字段"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    旧键 = "备注"
    新键 = "备注信息"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    旧键 = "状态"
    新键 = "订单状态"
    print("结果:", 重命名键(数据, 旧键, 新键))
    print("数据:", 数据)



from typing import Any, Callable, Dict

def 筛选键值对(
    数据: Dict[str, Any],
    条件函数: Callable[[str, Any], bool]
) -> Dict[str, Any]:
    """按条件函数筛选字典中的键值对，并返回新字典。

    功能说明:
        - 这个函数用于按条件函数筛选字典中的键值对，并返回新字典。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回空字典或约定结果，避免程序因为异常中断。

    Args:
        数据 (dict): 原始字典对象。
        条件函数 (Callable[[str, Any], bool]): 筛选判断函数。
        - 示例： lambda 键, 值: 键.startswith("user_")
        - 示例： lambda 键, 值: isinstance(值, int)

    Returns:
        dict[str, Any]:
        - 成功：返回筛选后的新字典；
        - 失败：返回空字典 {}。"""
    try:
        if not isinstance(数据, dict):
            return {}

        if not callable(条件函数):
            return {}

        return {
            str(键): 值
            for 键, 值 in 数据.items()
            if 条件函数(str(键), 值)
        }
    except Exception:
        return {}


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    条件函数 = lambda 键, 值: 键.startswith("名")
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    条件函数 = lambda 键, 值: isinstance(值, int)
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    条件函数 = lambda 键, 值: True
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    条件函数 = 123
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    条件函数 = lambda 键, 值: 值 not in (None, "")
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    条件函数 = lambda 键, 值: 键 in ("订单号", "状态")
    print("结果:", 筛选键值对(数据, 条件函数))
    print("数据:", 数据)



from typing import Any, Dict, Iterable

def 只保留键(
    数据: Dict[str, Any],
    保留键列表: Iterable[Any]
) -> Dict[str, Any]:
    """根据给定的键列表，仅保留字典中对应的键值对。

    功能说明:
        - 这个函数用于根据给定的键列表，仅保留字典中对应的键值对。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回空字典或约定结果，避免程序因为异常中断。

    Args:
        数据 (dict): 原始字典对象。
        保留键列表 (Iterable): 需要保留的键集合。

    Returns:
        dict:
        - 成功：仅包含指定键的新字典；
        - 失败：空字典 {}。"""
    try:
        if not isinstance(数据, dict):
            return {}

        if not 保留键列表:
            return {}

        目标键集合 = {str(键) for 键 in 保留键列表}

        return {
            str(键): 值
            for 键, 值 in 数据.items()
            if str(键) in 目标键集合
        }
    except Exception:
        return {}


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    保留键列表 = ["名称", "城市"]
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    保留键列表 = ("name", "phone")
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    保留键列表 = []
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    保留键列表 = "名称"
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    保留键列表 = ["备注", "标签"]
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    保留键列表 = ["订单号", "状态", "金额"]
    print("结果:", 只保留键(数据, 保留键列表))
    print("数据:", 数据)



from datetime import datetime


def 是否今天(时间字符串: str) -> bool:
    """判断一个时间是不是今天。

    功能说明:
        - 这个函数用于判断传入的时间，日期部分是否和今天相同。
        - 它只比较年月日，不比较具体时分秒。
        - 输入内容必须是 ``YYYY-MM-DD HH:MM:SS`` 格式。
        - 如果输入格式不对，函数直接返回 ``False``。

    Args:
        时间字符串: 要判断的时间字符串。

    Returns:
        属于今天返回 ``True``，否则返回 ``False``。
    """
    try:
        输入日期 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S").date()
        当前日期 = datetime.now().date()
        return 输入日期 == 当前日期
    except Exception:
        return False


if __name__ == "__main__":
    今天时间 = datetime.now().strftime("%Y-%m-%d 09:30:00")
    昨天时间 = datetime.now().replace(day=datetime.now().day).strftime("%Y-%m-%d %H:%M:%S")

    print("===== 示例1：传入今天的时间 =====")
    print("结果:", 是否今天(今天时间))

    print("\n===== 示例2：传入当前系统时间字符串 =====")
    当前时间 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    print("结果:", 是否今天(当前时间))

    print("\n===== 示例3：传入过去某一天的时间 =====")
    print("结果:", 是否今天("2020-01-01 12:00:00"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 是否今天("2026/03/20"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 是否今天(""))

    print("\n===== 示例6：应用场景-筛选今天提交的订单 =====")
    订单时间 = datetime.now().strftime("%Y-%m-%d 18:20:00")
    print("订单是否今天提交:", 是否今天(订单时间))



from typing import Any, Tuple


def 取重复率(元组数据: Tuple[Any, ...]):
    """返回元组成员的重复率。

    功能说明:
        - 这个函数用于返回元组成员的重复率。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    计算方式:
        ``(总成员数量 - 唯一成员数量) / 总成员数量``
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return None

        唯一成员 = []
        for 元素 in 元组数据:
            if 元素 not in 唯一成员:
                唯一成员.append(元素)
        return (len(元组数据) - len(唯一成员)) / len(元组数据)
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础重复率 =====")
    数据 = (1, 2, 2, 3, 1, 4)
    print("结果:", 取重复率(数据))

    print("\n===== 示例2：全部唯一 =====")
    数据 = ("a", "b", "c")
    print("结果:", 取重复率(数据))

    print("\n===== 示例3：全部相同 =====")
    数据 = ("a", "a", "a")
    print("结果:", 取重复率(数据))

    print("\n===== 示例4：包含不可哈希成员 =====")
    数据 = ([1], [1], {"x": 1}, {"x": 1})
    print("结果:", 取重复率(数据))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取重复率(数据))

    print("\n===== 示例6：应用场景-统计标签重复率 =====")
    标签列表 = ("已支付", "待发货", "已支付", "高优先级", "待发货")
    print("结果:", 取重复率(标签列表))






from datetime import datetime


def 时间转时分秒(时间字符串: str) -> tuple[int, int, int] | None:
    """把标准时间字符串拆成“时、分、秒”。

    功能说明:
        - 这个函数用于把 ``YYYY-MM-DD HH:MM:SS`` 这种标准时间拆成三个整数。
        - 返回结果是 ``(时, 分, 秒)`` 这样的元组。
        - 适合继续做时间显示、倒计时或条件判断。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: 标准时间字符串。

    Returns:
        成功时返回 ``(时, 分, 秒)``；失败时返回 ``None``。
    """
    try:
        时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return 时间对象.hour, 时间对象.minute, 时间对象.second
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：拆分普通时间 =====")
    print("结果:", 时间转时分秒("2026-03-20 10:30:45"))

    print("\n===== 示例2：拆分个位数时间 =====")
    print("结果:", 时间转时分秒("2026-03-20 05:06:07"))

    print("\n===== 示例3：拆分午夜时间 =====")
    print("结果:", 时间转时分秒("2026-03-20 00:00:00"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 时间转时分秒("2026/03/20 10:30:45"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 时间转时分秒(""))

    print("\n===== 示例6：应用场景-把签到时间拆成时分秒后分别显示 =====")
    时, 分, 秒 = 时间转时分秒("2026-03-20 08:15:30") or (None, None, None)
    print("结果:", 时, 分, 秒)



from typing import Any, Dict

def 键映射(
    数据: Dict[str, Any],
    键映射表: Dict[Any, Any]
) -> Dict[str, Any]:
    """根据给定映射表批量重命名字典中的键，并返回新字典。

    功能说明:
        - 这个函数用于根据给定映射表批量重命名字典中的键，并返回新字典。
        - 它会把原始字典整理成更容易继续使用的结果，适合做数据预处理。
        - 当输入不符合要求时，函数会返回空字典或约定结果，避免程序因为异常中断。

    Args:
        数据 (dict): 原始字典对象。
        键映射表 (dict): 键名映射关系表。
        - 示例： {"name": "名称", "age": "年龄"}

    Returns:
        dict[str, Any]:
        - 成功：返回批量重命名后的新字典；
        - 失败：返回空字典 {}。"""
    try:
        if not isinstance(数据, dict):
            return {}

        if not isinstance(键映射表, dict):
            return {}

        标准映射表 = {
            str(旧键): str(新键)
            for 旧键, 新键 in 键映射表.items()
        }

        结果字典: Dict[str, Any] = {}
        for 键, 值 in 数据.items():
            原键名 = str(键)
            新键名 = 标准映射表.get(原键名, 原键名)
            结果字典[新键名] = 值

        return 结果字典
    except Exception:
        return {}


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    键映射表 = {"name": "名称", "age": "年龄"}
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    键映射表 = {"phone": "手机号"}
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键映射表 = {}
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键映射表 = []
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    键映射表 = {"备注": "说明"}
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    键映射表 = {"order_id": "订单号", "status": "状态"}
    print("结果:", 键映射(数据, 键映射表))
    print("数据:", 数据)
    print("键映射表:", 键映射表)



import calendar
from datetime import datetime


def 取月份天数(时间字符串: str | None = None) -> int | None:
    """返回指定日期所在月份一共有多少天。

    功能说明:
        - 这个函数用于查看某个月份一共有多少天。
        - 支持传入日期，也支持传入完整时间。
        - 不传参数时，默认查看当前月份。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: ``YYYY-MM-DD`` 或 ``YYYY-MM-DD HH:MM:SS`` 格式的日期时间字符串。

    Returns:
        成功时返回月份天数；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            年份 = datetime.now().year
            月份 = datetime.now().month
        else:
            时间字符串 = 时间字符串.strip()
            if len(时间字符串) == 10:
                时间对象 = datetime.strptime(时间字符串, "%Y-%m-%d")
            else:
                时间对象 = datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S")
            年份 = 时间对象.year
            月份 = 时间对象.month
        return calendar.monthrange(年份, 月份)[1]
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：查看 2026-03 所在月份天数 =====")
    print("结果:", 取月份天数("2026-03-20"))

    print("\n===== 示例2：查看闰年 2 月天数 =====")
    print("结果:", 取月份天数("2024-02-20"))

    print("\n===== 示例3：传入完整时间 =====")
    print("结果:", 取月份天数("2026-04-15 10:00:00"))

    print("\n===== 示例4：不传参数，查看当前月份天数 =====")
    print("结果:", 取月份天数())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 取月份天数("2026/03/20"))

    print("\n===== 示例6：应用场景-判断本月是否需要排 31 天班表 =====")
    print("结果:", 取月份天数("2026-07-01"))



from datetime import datetime, timedelta


def 时间加小时(时间字符串: str, 小时数: int) -> str | None:
    """在原时间上增加或减少指定小时数。

    功能说明:
        - 这个函数用于把一个标准时间往后推几小时，或者往前退几小时。
        - 传入的时间格式必须是 ``YYYY-MM-DD HH:MM:SS``。
        - ``小时数`` 可以是负数，负数表示往前推。
        - 输入格式不正确或参数不能参与计算时，函数返回 ``None``。

    Args:
        时间字符串: 原始时间字符串。
        小时数: 要增加的小时数，负数表示减少。

    Returns:
        成功时返回计算后的时间字符串；失败时返回 ``None``。
    """
    try:
        原时间 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        新时间 = 原时间 + timedelta(hours=小时数)
        return 新时间.strftime("%Y-%m-%d %H:%M:%S")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：在原时间上加 2 小时 =====")
    print("结果:", 时间加小时("2026-03-20 10:00:00", 2))

    print("\n===== 示例2：在原时间上减 5 小时 =====")
    print("结果:", 时间加小时("2026-03-20 10:00:00", -5))

    print("\n===== 示例3：跨天增加小时 =====")
    print("结果:", 时间加小时("2026-03-20 23:30:00", 3))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 时间加小时("2026/03/20 10:00:00", 2))

    print("\n===== 示例5：小时数不是整数 =====")
    print("结果:", 时间加小时("2026-03-20 10:00:00", "2"))

    print("\n===== 示例6：应用场景-计算工单 4 小时后的超时点 =====")
    建单时间 = "2026-03-20 09:15:00"
    超时时间 = 时间加小时(建单时间, 4)
    print("超时时间:", 超时时间)



from datetime import datetime


def 获取相差分钟数(时间1: str, 时间2: str) -> float | None:
    """计算两个时间相差多少分钟。

    功能说明:
        - 这个函数用于计算两个标准时间之间的分钟差。
        - 结果保留正负号，第二个时间更晚时返回正数，更早时返回负数。
        - 适合做排队时长、播放时长和响应时间统计。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间1: 起始时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。
        时间2: 结束时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。

    Returns:
        成功时返回分钟差；失败时返回 ``None``。
    """
    try:
        t1 = datetime.strptime(时间1.strip(), "%Y-%m-%d %H:%M:%S")
        t2 = datetime.strptime(时间2.strip(), "%Y-%m-%d %H:%M:%S")
        return (t2 - t1).total_seconds() / 60
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：计算相差 5 分钟 =====")
    print("结果:", 获取相差分钟数("2026-03-20 10:00:00", "2026-03-20 10:05:00"))

    print("\n===== 示例2：计算带小数的分钟差 =====")
    print("结果:", 获取相差分钟数("2026-03-20 10:00:30", "2026-03-20 10:05:00"))

    print("\n===== 示例3：第二个时间更早 =====")
    print("结果:", 获取相差分钟数("2026-03-20 10:05:00", "2026-03-20 10:00:00"))

    print("\n===== 示例4：两个时间相同 =====")
    print("结果:", 获取相差分钟数("2026-03-20 10:00:00", "2026-03-20 10:00:00"))

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 获取相差分钟数("2026/03/20", "2026-03-20 10:05:00"))

    print("\n===== 示例6：应用场景-计算客服首响用了多少分钟 =====")
    print("结果:", 获取相差分钟数("2026-03-20 09:00:00", "2026-03-20 09:18:30"))



from typing import Any, Dict

def 合并(
    目标字典: Dict[str, Any],
    来源字典: Dict[str, Any]
) -> bool:
    """将来源字典中的键值对合并到目标字典中。

    功能说明:
        - 这个函数用于将来源字典中的键值对合并到目标字典中。
        - 它适合把两份字典数据整理到一起，常用于默认配置、补充字段或对比更新。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        目标字典 (dict): 接收合并结果的目标字典。
        来源字典 (dict): 提供键值对的来源字典。

    Returns:
        bool:
        True  - 合并操作已成功执行（或来源为空）；
        False - 参数非法或发生异常。"""
    try:
        if not isinstance(目标字典, dict):
            return False

        if not isinstance(来源字典, dict):
            return False

        目标字典.update(来源字典)
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    目标字典 = {"名称": "zfx"}
    来源字典 = {"城市": "上海"}
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)

    print("\n===== 示例2：常见变体 =====")
    目标字典 = {"名称": "zfx", "城市": "上海"}
    来源字典 = {"名称": "new", "电话": "123"}
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)

    print("\n===== 示例3：边界情况 =====")
    目标字典 = {}
    来源字典 = {}
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)

    print("\n===== 示例4：异常情况 =====")
    目标字典 = []
    来源字典 = []
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)

    print("\n===== 示例5：特殊值情况 =====")
    目标字典 = {"配置": {"端口": 3306}}
    来源字典 = {"配置": {"主机": "127.0.0.1"}}
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    目标字典 = {"商品": "鼠标", "库存": 20}
    来源字典 = {"库存": 50, "状态": "在售"}
    print("结果:", 合并(目标字典, 来源字典))
    print("目标字典:", 目标字典)
    print("来源字典:", 来源字典)



from datetime import datetime


def 取当前分钟() -> int:
    """返回当前系统分钟数。

    功能说明:
        - 这个函数用于获取当前时间里的分钟部分。
        - 返回结果是整数，范围是 ``0`` 到 ``59``。
        - 适合做时间展示、分钟级判断或拼接提示语。

    Returns:
        返回当前分钟，例如 ``25``。
    """
    return datetime.now().minute


if __name__ == "__main__":
    print("===== 示例1：直接获取当前分钟 =====")
    print("结果:", 取当前分钟())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取当前分钟()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：判断是否过了半点 =====")
    print("结果:", 取当前分钟() >= 30)

    print("\n===== 示例4：用于拼接时间提示 =====")
    提示 = f"当前分钟：{取当前分钟()} 分"
    print("结果:", 提示)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取当前分钟())
    print("结果2:", 取当前分钟())

    print("\n===== 示例6：应用场景-每到 30 分提醒一次 =====")
    是否提醒 = 取当前分钟() == 30
    print("是否触发提醒:", 是否提醒)



import calendar


def 取某年天数(年份: int) -> int | None:
    """返回指定年份一共有多少天。

    功能说明:
        - 这个函数用于查看某一年总共有 365 天还是 366 天。
        - 闰年返回 366，平年返回 365。
        - 年份不合法时，函数返回 ``None``。

    Args:
        年份: 要查询的年份。

    Returns:
        成功时返回年份天数；失败时返回 ``None``。
    """
    try:
        年份 = int(年份)
        if 年份 <= 0:
            return None
        return 366 if calendar.isleap(年份) else 365
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：查询平年天数 =====")
    print("结果:", 取某年天数(2026))

    print("\n===== 示例2：查询闰年天数 =====")
    print("结果:", 取某年天数(2024))

    print("\n===== 示例3：传入字符串年份 =====")
    print("结果:", 取某年天数("2000"))

    print("\n===== 示例4：年份为 0 =====")
    print("结果:", 取某年天数(0))

    print("\n===== 示例5：输入非法内容 =====")
    print("结果:", 取某年天数("二零二六"))

    print("\n===== 示例6：应用场景-判断这一年是否需要 366 天日历页 =====")
    print("结果:", 取某年天数(2028))



from datetime import datetime


def 补全日期为开始时间(日期字符串: str) -> str | None:
    """把日期补全成当天开始时间。

    功能说明:
        - 这个函数用于把 ``YYYY-MM-DD`` 补成 ``YYYY-MM-DD 00:00:00``。
        - 适合把用户只输入的日期，补成查询起始时间。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        日期字符串: 日期字符串，格式为 ``YYYY-MM-DD``。

    Returns:
        成功时返回完整开始时间；失败时返回 ``None``。
    """
    try:
        日期对象 = datetime.strptime(日期字符串.strip(), "%Y-%m-%d").date()
        return f"{日期对象} 00:00:00"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：普通日期补全开始时间 =====")
    print("结果:", 补全日期为开始时间("2026-03-20"))

    print("\n===== 示例2：月初日期补全开始时间 =====")
    print("结果:", 补全日期为开始时间("2026-03-01"))

    print("\n===== 示例3：闰年日期补全开始时间 =====")
    print("结果:", 补全日期为开始时间("2024-02-29"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 补全日期为开始时间("2026/03/20"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 补全日期为开始时间("2026-02-30"))

    print("\n===== 示例6：应用场景-把筛选日期补成数据库查询起点 =====")
    print("结果:", 补全日期为开始时间("2026-04-01"))



from datetime import datetime


def 时间戳转换为时间(时间戳):
    """把时间戳转换成标准时间字符串。

    功能说明:
        - 这个函数用于把秒级时间戳，转换成 ``YYYY-MM-DD HH:MM:SS`` 这种常见时间格式。
        - 输入可以是整数，也可以是能转成整数的数字字符串。
        - 如果传入的内容不能转换成有效时间戳，函数返回 ``False``。

    Args:
        时间戳: 秒级时间戳，可以是整数或数字字符串。

    Returns:
        成功时返回标准时间字符串；失败时返回 ``False``。
    """
    try:
        时间对象 = datetime.fromtimestamp(int(时间戳))
        时间字符串 = 时间对象.strftime("%Y-%m-%d %H:%M:%S")
        return 时间字符串
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：整数时间戳转时间 =====")
    print("结果:", 时间戳转换为时间(1736800467))

    print("\n===== 示例2：字符串时间戳转时间 =====")
    print("结果:", 时间戳转换为时间("1736800467"))

    print("\n===== 示例3：时间戳 0 对应的时间 =====")
    print("结果:", 时间戳转换为时间(0))

    print("\n===== 示例4：输入非数字字符串 =====")
    print("结果:", 时间戳转换为时间("abc"))

    print("\n===== 示例5：输入空值 =====")
    print("结果:", 时间戳转换为时间(None))

    print("\n===== 示例6：应用场景-把日志里的时间戳转成人能看懂的时间 =====")
    日志记录 = {"event": "用户登录", "created_at": 1736800467}
    可读时间 = 时间戳转换为时间(日志记录["created_at"])
    print("日志时间:", 可读时间)



from datetime import datetime


def 获取时间间隔(时间1: str, 时间2: str, 单位: int = 1) -> float | None:
    """计算两个时间之间相差多少。

    功能说明:
        - 这个函数用于计算两个标准时间之间的差值。
        - 你可以选择结果按毫秒、秒、分钟或小时返回。
        - 返回值保留正负号，也就是说如果第二个时间更早，结果会是负数。
        - 输入格式不正确或单位参数不合法时，函数返回 ``None``。

    Args:
        时间1: 起始时间字符串。
        时间2: 结束时间字符串。
        单位: 返回单位，``0`` 毫秒，``1`` 秒，``2`` 分钟，``3`` 小时。

    Returns:
        成功时返回时间差；失败时返回 ``None``。
    """
    try:
        t1 = datetime.strptime(时间1.strip(), "%Y-%m-%d %H:%M:%S")
        t2 = datetime.strptime(时间2.strip(), "%Y-%m-%d %H:%M:%S")
        秒差 = (t2 - t1).total_seconds()

        match 单位:
            case 0:
                return 秒差 * 1000
            case 1:
                return 秒差
            case 2:
                return 秒差 / 60
            case 3:
                return 秒差 / 3600
            case _:
                return None
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：按秒计算两个时间的间隔 =====")
    print("结果:", 获取时间间隔("2026-03-20 10:00:00", "2026-03-20 10:05:30", 1))

    print("\n===== 示例2：按分钟计算两个时间的间隔 =====")
    print("结果:", 获取时间间隔("2026-03-20 10:00:00", "2026-03-20 11:30:00", 2))

    print("\n===== 示例3：按小时计算两个时间的间隔 =====")
    print("结果:", 获取时间间隔("2026-03-20 08:00:00", "2026-03-20 20:00:00", 3))

    print("\n===== 示例4：第二个时间更早，结果会是负数 =====")
    print("结果:", 获取时间间隔("2026-03-20 10:00:00", "2026-03-20 09:30:00", 1))

    print("\n===== 示例5：单位参数不合法 =====")
    print("结果:", 获取时间间隔("2026-03-20 10:00:00", "2026-03-20 10:05:30", 9))

    print("\n===== 示例6：应用场景-计算一次直播持续了多少分钟 =====")
    开播时间 = "2026-03-20 19:00:00"
    下播时间 = "2026-03-20 21:45:00"
    print("直播时长(分钟):", 获取时间间隔(开播时间, 下播时间, 2))



from datetime import datetime


def 取当前时分() -> str:
    """返回当前系统的时分字符串。

    功能说明:
        - 这个函数用于获取当前时间中的小时和分钟，不返回秒数。
        - 返回格式固定为 ``HH:MM``。
        - 适合做界面时间显示、排班时间展示和简单提醒文案。

    Returns:
        返回当前时分字符串，例如 ``16:25``。
    """
    return datetime.now().strftime("%H:%M")


if __name__ == "__main__":
    print("===== 示例1：直接获取当前时分 =====")
    print("结果:", 取当前时分())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取当前时分()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：用于页面顶部显示当前时分 =====")
    标题 = f"现在时间：{取当前时分()}"
    print("结果:", 标题)

    print("\n===== 示例4：用于拼接预约提示 =====")
    提示 = f"请在 {取当前时分()} 前完成提交"
    print("结果:", 提示)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取当前时分())
    print("结果2:", 取当前时分())

    print("\n===== 示例6：应用场景-给聊天消息显示简化时间 =====")
    消息 = {"text": "已发送", "time": 取当前时分()}
    print("消息:", 消息)



from numbers import Number
from typing import Any, Tuple


def 取数字成员数量(元组数据: Tuple[Any, ...]):
    """返回元组中数字成员的数量。

    功能说明:
        - 这个函数用于返回元组中数字成员的数量。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。
"""
    try:
        if not isinstance(元组数据, tuple):
            return None
        return sum(1 for 元素 in 元组数据 if isinstance(元素, Number))
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础数字统计 =====")
    数据 = (1, 2.5, "3", None)
    print("结果:", 取数字成员数量(数据))

    print("\n===== 示例2：布尔值也属于数字 =====")
    数据 = (True, False, 1, 2)
    print("结果:", 取数字成员数量(数据))

    print("\n===== 示例3：复数也属于数字 =====")
    数据 = (1 + 2j, 3, "x")
    print("结果:", 取数字成员数量(数据))

    print("\n===== 示例4：没有数字 =====")
    数据 = ("a", None, {})
    print("结果:", 取数字成员数量(数据))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取数字成员数量(数据))

    print("\n===== 示例6：应用场景-统计金额列中的数值个数 =====")
    金额列 = (1200.5, 980, "", None, 300)
    print("结果:", 取数字成员数量(金额列))






from datetime import datetime


def 取本年开始时间(时间字符串: str | None = None) -> str | None:
    """返回指定日期所在年份的开始时间。

    功能说明:
        - 这个函数用于找到某一年 1 月 1 日的 ``00:00:00``。
        - 支持传入日期，也支持传入完整时间。
        - 不传参数时，默认按当前年份计算。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: ``YYYY-MM-DD`` 或 ``YYYY-MM-DD HH:MM:SS`` 格式的日期时间字符串。

    Returns:
        成功时返回本年开始时间；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            年份 = datetime.now().year
        else:
            时间字符串 = 时间字符串.strip()
            if len(时间字符串) == 10:
                年份 = datetime.strptime(时间字符串, "%Y-%m-%d").year
            else:
                年份 = datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S").year
        return f"{年份}-01-01 00:00:00"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：传入日期，取本年开始时间 =====")
    print("结果:", 取本年开始时间("2026-03-20"))

    print("\n===== 示例2：传入完整时间，取本年开始时间 =====")
    print("结果:", 取本年开始时间("2026-03-20 18:30:45"))

    print("\n===== 示例3：不传参数，取当前年份开始时间 =====")
    print("结果:", 取本年开始时间())

    print("\n===== 示例4：跨年输入 =====")
    print("结果:", 取本年开始时间("2024-12-31"))

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 取本年开始时间("2026/03/20"))

    print("\n===== 示例6：应用场景-生成年度报表起始时间 =====")
    print("年报开始:", 取本年开始时间("2026-08-15 09:00:00"))



from datetime import datetime


def 时间转换为时间戳(时间字符串):
    """把标准时间字符串转换成秒级时间戳。

    功能说明:
        - 这个函数用于把 ``YYYY-MM-DD HH:MM:SS`` 格式的时间，转换成整数时间戳。
        - 转成时间戳后，更适合做时间比较、排序和存储。
        - 如果输入的时间格式不正确，函数返回 ``False``。

    Args:
        时间字符串: 标准时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。

    Returns:
        成功时返回整数时间戳；失败时返回 ``False``。
    """
    try:
        时间对象 = datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S")
        时间戳 = int(时间对象.timestamp())
        return 时间戳
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：标准时间转时间戳 =====")
    print("结果:", 时间转换为时间戳("2025-01-13 22:34:27"))

    print("\n===== 示例2：另一个标准时间转时间戳 =====")
    print("结果:", 时间转换为时间戳("2026-03-20 08:00:00"))

    print("\n===== 示例3：同一天不同时间会得到不同的时间戳 =====")
    print("结果1:", 时间转换为时间戳("2026-03-20 08:00:00"))
    print("结果2:", 时间转换为时间戳("2026-03-20 08:00:10"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 时间转换为时间戳("2026/03/20 08:00:00"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 时间转换为时间戳("2026-02-30 08:00:00"))

    print("\n===== 示例6：应用场景-把用户提交时间转成可排序的数字 =====")
    提交记录 = {"user": "张三", "submitted_at": "2026-03-20 15:45:10"}
    print("提交时间戳:", 时间转换为时间戳(提交记录["submitted_at"]))



from __future__ import annotations

from typing import Any, List, Sequence, Union


_路径类型 = Union[str, Sequence[Any]]


def 设置值_路径(
    数据: Any,
    键路径: _路径类型,
    值: Any,
    分隔符: str = ".",
    键转字符串: bool = True,
) -> bool:
    """根据路径把值写入嵌套字典或列表中。

    功能说明:
        - 这个函数用于根据路径把值写入嵌套字典或列表中。
        - 当中间层还不存在时，它会自动帮你补出需要的字典或列表结构。
        - 它适合处理接口组装、配置写入、动态生成多层业务数据这类场景。

    Args:
        数据: 通常为 dict 或 list 的嵌套结构。
        键路径: 路径字符串或路径序列。
            - 字符串示例： "a.b.0.c"
            - 列表示例： ["a", "b", 0, "c"]
        值: 需要写入目标路径的值。
        分隔符: 字符串路径的分隔符，默认 "."。
        键转字符串: 当走 dict 写入时，是否将键统一转为 str。默认 True。

    Returns:
        写入成功时返回 ``True``；写入失败时返回 ``False``。
    """
    try:
        if isinstance(键路径, str):
            if 键路径 == "":
                return False
            路径列表: List[Any] = 键路径.split(分隔符)
        elif isinstance(键路径, (list, tuple)):
            if len(键路径) == 0:
                return False
            路径列表 = list(键路径)
        else:
            return False

        if not isinstance(数据, (dict, list)):
            return False

        当前 = 数据

        for 索引位置, 段 in enumerate(路径列表):
            是否最后一段 = 索引位置 == len(路径列表) - 1
            下一段 = None if 是否最后一段 else 路径列表[索引位置 + 1]

            if isinstance(当前, dict):
                键名 = str(段) if 键转字符串 else 段

                if 是否最后一段:
                    当前[键名] = 值
                    return True

                if 键名 not in 当前:
                    try:
                        需要列表 = not isinstance(下一段, bool) and (
                            isinstance(下一段, int) or str(下一段).isdigit()
                        )
                    except Exception:
                        需要列表 = False
                    当前[键名] = [] if 需要列表 else {}

                if not isinstance(当前[键名], (dict, list)):
                    return False

                当前 = 当前[键名]
                continue

            if isinstance(当前, list):
                try:
                    目标索引 = 段 if isinstance(段, int) else int(str(段))
                except Exception:
                    return False

                if 目标索引 < 0:
                    return False

                while len(当前) <= 目标索引:
                    当前.append(None)

                if 是否最后一段:
                    当前[目标索引] = 值
                    return True

                if 当前[目标索引] is None:
                    try:
                        需要列表 = not isinstance(下一段, bool) and (
                            isinstance(下一段, int) or str(下一段).isdigit()
                        )
                    except Exception:
                        需要列表 = False
                    当前[目标索引] = [] if 需要列表 else {}

                if not isinstance(当前[目标索引], (dict, list)):
                    return False

                当前 = 当前[目标索引]
                continue

            return False

        return False
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {}
    print("结果:", 设置值_路径(数据, "用户.信息.0.城市", "上海"))
    print("数据:", 数据)

    print("\n===== 示例2：使用列表路径 =====")
    数据 = {}
    print("结果:", 设置值_路径(数据, ["用户", "信息", 0, "年龄"], 18))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况-空路径 =====")
    数据 = {}
    print("结果:", 设置值_路径(数据, "", "上海"))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况-数据不是字典或列表 =====")
    数据 = "不是字典"
    print("结果:", 设置值_路径(数据, "用户.信息.0.城市", "上海"))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况-覆盖已有值 =====")
    数据 = {"用户": {"信息": [{"城市": "北京"}]}}
    print("结果:", 设置值_路径(数据, "用户.信息.0.城市", None))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-写入订单收货人信息 =====")
    数据 = {}
    print("结果:", 设置值_路径(数据, "订单.收货信息.0.联系人", "张三"))
    print("数据:", 数据)



from datetime import datetime, timedelta


def 取前N天日期(天数: int) -> str | None:
    """返回当前日期往前推 N 天后的日期。

    功能说明:
        - 这个函数用于计算几天前是哪一天。
        - 传入 ``3`` 就表示返回 3 天前的日期。
        - 返回格式固定为 ``YYYY-MM-DD``。
        - 如果天数不是整数，函数返回 ``None``。

    Args:
        天数: 要往前推的天数。

    Returns:
        成功时返回日期字符串；失败时返回 ``None``。
    """
    try:
        return (datetime.now() - timedelta(days=天数)).strftime("%Y-%m-%d")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：取 3 天前的日期 =====")
    print("结果:", 取前N天日期(3))

    print("\n===== 示例2：取 0 天前的日期，也就是今天 =====")
    print("结果:", 取前N天日期(0))

    print("\n===== 示例3：取 30 天前的日期 =====")
    print("结果:", 取前N天日期(30))

    print("\n===== 示例4：传入负数，相当于往后推 =====")
    print("结果:", 取前N天日期(-2))

    print("\n===== 示例5：天数不是整数 =====")
    print("结果:", 取前N天日期("3"))

    print("\n===== 示例6：应用场景-查询最近 7 天统计起始日期 =====")
    起始日期 = 取前N天日期(7)
    print("查询起始日期:", 起始日期)



import calendar


def 取某季度结束时间(年份: int, 季度: int) -> str | None:
    """返回指定年份和季度的结束时间。

    功能说明:
        - 这个函数用于直接指定“某一年第几季度”，然后得到这个季度结束的时刻。
        - 季度只能填写 ``1``、``2``、``3``、``4``。
        - 如果年份或季度不合法，函数返回 ``None``。

    Args:
        年份: 要查询的年份。
        季度: 要查询的季度。

    Returns:
        成功时返回季度结束时间；失败时返回 ``None``。
    """
    try:
        年份 = int(年份)
        季度 = int(季度)
        if 年份 <= 0 or 季度 not in (1, 2, 3, 4):
            return None
        结束月份 = 季度 * 3
        月末天数 = calendar.monthrange(年份, 结束月份)[1]
        return f"{年份:04}-{结束月份:02}-{月末天数:02} 23:59:59"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：取 2026 年第 1 季度结束时间 =====")
    print("结果:", 取某季度结束时间(2026, 1))

    print("\n===== 示例2：取 2026 年第 3 季度结束时间 =====")
    print("结果:", 取某季度结束时间(2026, 3))

    print("\n===== 示例3：传入字符串参数 =====")
    print("结果:", 取某季度结束时间("2024", "4"))

    print("\n===== 示例4：季度超出范围 =====")
    print("结果:", 取某季度结束时间(2026, 5))

    print("\n===== 示例5：年份不合法 =====")
    print("结果:", 取某季度结束时间(0, 1))

    print("\n===== 示例6：应用场景-生成历史季度查询截止时间 =====")
    print("查询结束:", 取某季度结束时间(2025, 2))



from typing import Any, Tuple


def 验证_是否等长二维元组(元组数据: Tuple[Tuple[Any, ...], ...]) -> bool:
    """验证是否为每行长度一致的二维元组。

    功能说明:
        - 这个函数用于验证是否为每行长度一致的二维元组。
        - 常用于先判断元组数据是否满足某个条件，再决定后续要不要继续处理。
        - 返回结果一般是 ``True`` 或 ``False``，适合直接写在 ``if`` 判断里使用。

    Args:
        元组数据: 待验证的数据。

    Returns:
        是等长二维元组时返回 ``True``，否则返回 ``False``。
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return False

        第一行长度 = None
        for 项 in 元组数据:
            if not isinstance(项, tuple):
                return False
            if 第一行长度 is None:
                第一行长度 = len(项)
            elif len(项) != 第一行长度:
                return False
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：标准等长二维元组 =====")
    数据 = ((1, 2, 3), (4, 5, 6))
    print("结果:", 验证_是否等长二维元组(数据))

    print("\n===== 示例2：单行二维元组 =====")
    数据 = (("张三", 18, "技术部"),)
    print("结果:", 验证_是否等长二维元组(数据))

    print("\n===== 示例3：行长度不一致 =====")
    数据 = ((1, 2), (3, 4, 5))
    print("结果:", 验证_是否等长二维元组(数据))

    print("\n===== 示例4：存在非法子项 =====")
    数据 = ((1, 2), [3, 4])
    print("结果:", 验证_是否等长二维元组(数据))

    print("\n===== 示例5：空二维元组 =====")
    数据 = ()
    print("结果:", 验证_是否等长二维元组(数据))

    print("\n===== 示例6：应用场景-预检报表是否适合转置 =====")
    报表 = (
        ("日期", "2026-03-18", "2026-03-19"),
        ("销售额", 1200, 1350),
        ("订单数", 32, 35),
    )
    print("结果:", 验证_是否等长二维元组(报表))






from typing import Any, Dict

def 清空字典(数据: Dict[str, Any]) -> bool:
    """清空字典中的所有键值对。

    功能说明:
        - 这个函数用于清空字典中的所有键值对。
        - 它主要返回 True 或 False，适合直接写在 if 判断里控制后续流程。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        数据 (dict): 需要被清空的字典对象。

    Returns:
        bool:
        True  - 字典已成功清空（或原本为空）；
        False - 传入对象不是字典或发生异常。"""
    try:
        if not isinstance(数据, dict):
            return False

        数据.clear()
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    print("结果:", 清空字典(数据))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    print("结果:", 清空字典(数据))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    print("结果:", 清空字典(数据))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    print("结果:", 清空字典(数据))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    print("结果:", 清空字典(数据))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    print("结果:", 清空字典(数据))
    print("数据:", 数据)



def 秒数转时间字符串(秒数: int) -> str:
    """把总秒数转换成 ``HH:MM:SS`` 格式字符串。

    功能说明:
        - 这个函数用于把一个总秒数，转换成更容易看的时分秒格式。
        - 秒数可以超过 24 小时，函数会继续把小时往上累加。
        - 传入负数时会自动取绝对值。
        - 如果输入不能转成整数，函数返回 ``00:00:00``。

    Args:
        秒数: 要转换的总秒数。

    Returns:
        返回 ``HH:MM:SS`` 格式的字符串。
    """
    try:
        秒数 = abs(int(秒数))
        小时, 余数 = divmod(秒数, 3600)
        分钟, 秒 = divmod(余数, 60)
        return f"{小时:02}:{分钟:02}:{秒:02}"
    except Exception:
        return "00:00:00"


if __name__ == "__main__":
    print("===== 示例1：3661 秒转成时间字符串 =====")
    print("结果:", 秒数转时间字符串(3661))

    print("\n===== 示例2：0 秒转成时间字符串 =====")
    print("结果:", 秒数转时间字符串(0))

    print("\n===== 示例3：超过 24 小时的秒数 =====")
    print("结果:", 秒数转时间字符串(90061))

    print("\n===== 示例4：输入负数 =====")
    print("结果:", 秒数转时间字符串(-75))

    print("\n===== 示例5：输入不能转成整数的内容 =====")
    print("结果:", 秒数转时间字符串("abc"))

    print("\n===== 示例6：应用场景-把任务耗时秒数显示成时分秒 =====")
    任务耗时秒数 = 5482
    print("任务耗时:", 秒数转时间字符串(任务耗时秒数))



from typing import Any, Dict

def 添加键值对(
    数据: Dict[str, Any],
    键: Any,
    值: Any
) -> bool:
    """向给定字典中添加或更新一个键值对。

    功能说明:
        - 这个函数用于向给定字典中添加或更新一个键值对。
        - 它主要返回 True 或 False，适合直接写在 if 判断里控制后续流程。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        数据 (dict): 目标字典对象，必须为可变字典。
        键: 要添加或更新的键，内部将统一转换为字符串。
        值: 要写入字典的值，类型不限。

    Returns:
        bool:
        - True  ：键值对成功写入字典；
        - False ：传入对象不是字典或发生异常。"""
    try:
        if not isinstance(数据, dict):
            return False

        数据[str(键)] = 值
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    键 = "名称"
    值 = "新值"
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    键 = "name"
    值 = None
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键 = "不存在"
    值 = "空"
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键 = "名称"
    值 = 1
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    键 = "备注"
    值 = ""
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    键 = "状态"
    值 = "已发货"
    print("结果:", 添加键值对(数据, 键, 值))
    print("数据:", 数据)



from datetime import datetime


def 验证时间格式(时间字符串: str, 格式: str = "%Y-%m-%d %H:%M:%S") -> bool:
    """检查一个时间字符串是否符合指定格式。

    功能说明:
        - 这个函数用于验证时间字符串写得对不对。
        - 默认检查 ``YYYY-MM-DD HH:MM:SS`` 这种最常见的标准时间格式。
        - 你也可以自己传别的格式，让它帮你按新格式检查。
        - 只要格式不对或日期本身不存在，函数都会返回 ``False``。

    Args:
        时间字符串: 要验证的时间字符串。
        格式: 期望的时间格式。

    Returns:
        符合格式返回 ``True``，否则返回 ``False``。
    """
    try:
        datetime.strptime(时间字符串.strip(), 格式)
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：验证标准时间格式 =====")
    print("结果:", 验证时间格式("2026-03-20 10:30:45"))

    print("\n===== 示例2：标准格式但日期不存在 =====")
    print("结果:", 验证时间格式("2026-02-30 10:30:45"))

    print("\n===== 示例3：验证自定义日期格式 =====")
    print("结果:", 验证时间格式("2026/03/20", "%Y/%m/%d"))

    print("\n===== 示例4：自定义格式不匹配 =====")
    print("结果:", 验证时间格式("2026-03-20", "%Y/%m/%d"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 验证时间格式(""))

    print("\n===== 示例6：应用场景-先验证用户输入，再决定是否入库 =====")
    用户输入 = "2026-03-20 18:00:00"
    if 验证时间格式(用户输入):
        print("可以入库:", 用户输入)
    else:
        print("时间格式不正确")



from datetime import datetime


def 标准时间转ISO格式(时间字符串: str) -> str | None:
    """把标准时间字符串转成 ISO 格式字符串。

    功能说明:
        - 这个函数用于把 ``YYYY-MM-DD HH:MM:SS`` 转成 ``YYYY-MM-DDTHH:MM:SS``。
        - ISO 格式更适合接口传输和程序之间交换时间数据。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: 标准时间字符串。

    Returns:
        成功时返回 ISO 格式时间字符串；失败时返回 ``None``。
    """
    try:
        时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return 时间对象.isoformat(timespec="seconds")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：标准时间转 ISO 格式 =====")
    print("结果:", 标准时间转ISO格式("2026-03-20 10:30:45"))

    print("\n===== 示例2：午夜时间转 ISO 格式 =====")
    print("结果:", 标准时间转ISO格式("2026-03-20 00:00:00"))

    print("\n===== 示例3：跨年时间转 ISO 格式 =====")
    print("结果:", 标准时间转ISO格式("2026-12-31 23:59:59"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 标准时间转ISO格式("2026/03/20 10:30:45"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 标准时间转ISO格式(""))

    print("\n===== 示例6：应用场景-把数据库时间转成接口字段时间 =====")
    print("结果:", 标准时间转ISO格式("2026-03-20 18:00:00"))



from datetime import datetime


def 取系统时间戳():
    """返回当前系统时间戳。

    功能说明:
        - 这个函数用于获取当前系统时间对应的 Unix 时间戳，单位是秒。
        - 时间戳适合做排序、比较时间先后、保存到数据库等场景。
        - 如果获取失败，函数会返回 ``False``。

    Returns:
        成功时返回整数时间戳；失败时返回 ``False``。
    """
    try:
        当前时间戳 = int(datetime.now().timestamp())
        return 当前时间戳
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：直接获取当前时间戳 =====")
    print("结果:", 取系统时间戳())

    print("\n===== 示例2：查看返回值类型 =====")
    当前时间戳 = 取系统时间戳()
    print("结果:", 当前时间戳, "类型:", type(当前时间戳).__name__)

    print("\n===== 示例3：用于记录任务开始时间 =====")
    开始时间戳 = 取系统时间戳()
    print("任务开始时间戳:", 开始时间戳)

    print("\n===== 示例4：连续调用两次比较大小 =====")
    第一次 = 取系统时间戳()
    第二次 = 取系统时间戳()
    print("第一次:", 第一次)
    print("第二次:", 第二次)
    print("第二次是否大于等于第一次:", 第二次 >= 第一次)

    print("\n===== 示例5：用于拼接缓存键 =====")
    缓存键 = f"user_report_{取系统时间戳()}"
    print("结果:", 缓存键)

    print("\n===== 示例6：应用场景-给消息队列任务生成入队时间 =====")
    任务数据 = {
        "task_name": "同步库存",
        "queued_at": 取系统时间戳(),
    }
    print("任务数据:", 任务数据)



from datetime import datetime, timedelta


def 时间加分钟(时间字符串: str, 分钟数: int) -> str | None:
    """在原时间上增加或减少指定分钟数。

    功能说明:
        - 这个函数用于把一个标准时间往后推几分钟，或者往前退几分钟。
        - 传入的时间格式必须是 ``YYYY-MM-DD HH:MM:SS``。
        - ``分钟数`` 可以是负数，负数表示往前推。
        - 输入格式不正确或参数不能参与计算时，函数返回 ``None``。

    Args:
        时间字符串: 原始时间字符串。
        分钟数: 要增加的分钟数，负数表示减少。

    Returns:
        成功时返回计算后的时间字符串；失败时返回 ``None``。
    """
    try:
        原时间 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        新时间 = 原时间 + timedelta(minutes=分钟数)
        return 新时间.strftime("%Y-%m-%d %H:%M:%S")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：在原时间上加 15 分钟 =====")
    print("结果:", 时间加分钟("2026-03-20 10:00:00", 15))

    print("\n===== 示例2：在原时间上减 30 分钟 =====")
    print("结果:", 时间加分钟("2026-03-20 10:00:00", -30))

    print("\n===== 示例3：跨天增加分钟 =====")
    print("结果:", 时间加分钟("2026-03-20 23:50:00", 20))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 时间加分钟("2026/03/20 10:00:00", 15))

    print("\n===== 示例5：分钟数不是整数 =====")
    print("结果:", 时间加分钟("2026-03-20 10:00:00", "15"))

    print("\n===== 示例6：应用场景-给会议开始时间自动顺延 10 分钟 =====")
    会议开始 = "2026-03-20 14:30:00"
    实际开始 = 时间加分钟(会议开始, 10)
    print("实际开始时间:", 实际开始)



from datetime import datetime


def 日期转星期几(日期字符串: str) -> str:
    """把日期字符串转换成星期几。

    功能说明:
        - 这个函数用于判断某个日期是星期几。
        - 输入内容只需要写日期，格式为 ``YYYY-MM-DD``。
        - 返回结果是 ``星期一`` 到 ``星期日`` 这样的中文字符串。
        - 输入格式不正确时，函数返回空字符串 ``""``。

    Args:
        日期字符串: 日期字符串。

    Returns:
        成功时返回中文星期；失败时返回空字符串 ``""``。
    """
    try:
        日期对象 = datetime.strptime(日期字符串.strip(), "%Y-%m-%d")
        星期列表 = ["星期一", "星期二", "星期三", "星期四", "星期五", "星期六", "星期日"]
        return 星期列表[日期对象.weekday()]
    except Exception:
        return ""


if __name__ == "__main__":
    print("===== 示例1：普通日期转星期几 =====")
    print("结果:", 日期转星期几("2026-03-20"))

    print("\n===== 示例2：周末日期 =====")
    print("结果:", 日期转星期几("2026-03-22"))

    print("\n===== 示例3：闰年日期 =====")
    print("结果:", 日期转星期几("2024-02-29"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 日期转星期几("2026/03/20"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 日期转星期几("2026-02-30"))

    print("\n===== 示例6：应用场景-把活动日期显示成“日期+星期” =====")
    日期 = "2026-04-15"
    print("结果:", 日期, 日期转星期几(日期))



import calendar


def 取某月天数(年份: int, 月份: int) -> int | None:
    """返回指定年份和月份一共有多少天。

    功能说明:
        - 这个函数用于直接查询某年某月的天数。
        - 适合做日期校验、排班表生成和月度统计。
        - 月份必须在 ``1`` 到 ``12`` 之间。
        - 参数不合法时，函数返回 ``None``。

    Args:
        年份: 要查询的年份。
        月份: 要查询的月份。

    Returns:
        成功时返回月份天数；失败时返回 ``None``。
    """
    try:
        年份 = int(年份)
        月份 = int(月份)
        if 年份 <= 0 or 月份 not in range(1, 13):
            return None
        return calendar.monthrange(年份, 月份)[1]
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：查询 2026 年 3 月天数 =====")
    print("结果:", 取某月天数(2026, 3))

    print("\n===== 示例2：查询闰年 2 月天数 =====")
    print("结果:", 取某月天数(2024, 2))

    print("\n===== 示例3：传入字符串参数 =====")
    print("结果:", 取某月天数("2026", "11"))

    print("\n===== 示例4：月份超出范围 =====")
    print("结果:", 取某月天数(2026, 13))

    print("\n===== 示例5：年份不合法 =====")
    print("结果:", 取某月天数(0, 3))

    print("\n===== 示例6：应用场景-生成当月最后一天日期 =====")
    天数 = 取某月天数(2026, 9)
    print("结果:", f"2026-09-{天数:02}" if 天数 else None)



from typing import Any, Dict

def 获取差异(
    旧字典: Dict[str, Any],
    新字典: Dict[str, Any]
) -> Dict[str, Dict[str, Any]]:
    """比较两个字典，返回新增、删除、变化三类差异信息。

    功能说明:
        - 这个函数用于比较两个字典，返回新增、删除、变化三类差异信息。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回空字典或约定结果，避免程序因为异常中断。

    Args:
        旧字典 (dict): 作为对比基准的旧字典。
        新字典 (dict): 作为目标状态的新字典。

    Returns:
        dict[str, dict[str, Any]]:
        - 新增：仅存在于新字典中的键值对；
        - 删除：仅存在于旧字典中的键值对；
        - 变化：值发生变化的键，格式为 {"旧值": xxx, "新值": xxx}。"""
    try:
        空结果: Dict[str, Dict[str, Any]] = {
            "新增": {},
            "删除": {},
            "变化": {},
        }

        if not isinstance(旧字典, dict):
            return 空结果

        if not isinstance(新字典, dict):
            return 空结果

        结果 = {
            "新增": {},
            "删除": {},
            "变化": {},
        }

        旧键集合 = {str(键) for 键 in 旧字典.keys()}
        新键集合 = {str(键) for 键 in 新字典.keys()}

        旧值映射 = {str(键): 值 for 键, 值 in 旧字典.items()}
        新值映射 = {str(键): 值 for 键, 值 in 新字典.items()}

        for 键 in 新键集合 - 旧键集合:
            结果["新增"][键] = 新值映射[键]

        for 键 in 旧键集合 - 新键集合:
            结果["删除"][键] = 旧值映射[键]

        for 键 in 旧键集合 & 新键集合:
            if 旧值映射[键] != 新值映射[键]:
                结果["变化"][键] = {
                    "旧值": 旧值映射[键],
                    "新值": 新值映射[键],
                }

        return 结果
    except Exception:
        return {
            "新增": {},
            "删除": {},
            "变化": {},
        }


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    旧字典 = {"a": 1, "b": 2, "c": 3}
    新字典 = {"b": 2, "c": 4, "d": 5}
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)

    print("\n===== 示例2：常见变体 =====")
    旧字典 = {"名称": "zfx", "城市": "上海"}
    新字典 = {"城市": "上海", "名称": "zfx"}
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)

    print("\n===== 示例3：边界情况 =====")
    旧字典 = {}
    新字典 = {}
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)

    print("\n===== 示例4：异常情况 =====")
    旧字典 = []
    新字典 = []
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)

    print("\n===== 示例5：特殊值情况 =====")
    旧字典 = {"配置": {"端口": 3306}, "debug": False}
    新字典 = {"配置": {"端口": 3306}, "debug": False}
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    旧字典 = {"订单号": "A001", "状态": "待支付", "金额": 99}
    新字典 = {"状态": "待支付"}
    print("结果:", 获取差异(旧字典, 新字典))
    print("旧字典:", 旧字典)
    print("新字典:", 新字典)



from datetime import datetime


def 取当前秒() -> int:
    """返回当前系统秒数。

    功能说明:
        - 这个函数用于获取当前时间里的秒数部分。
        - 返回结果是整数，范围是 ``0`` 到 ``59``。
        - 适合做秒级显示、倒计时界面或调试输出。

    Returns:
        返回当前秒，例如 ``30``。
    """
    return datetime.now().second


if __name__ == "__main__":
    print("===== 示例1：直接获取当前秒 =====")
    print("结果:", 取当前秒())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取当前秒()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：判断是否在前 30 秒 =====")
    print("结果:", 取当前秒() < 30)

    print("\n===== 示例4：用于拼接秒级提示 =====")
    提示 = f"当前秒：{取当前秒()} 秒"
    print("结果:", 提示)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取当前秒())
    print("结果2:", 取当前秒())

    print("\n===== 示例6：应用场景-在每分钟第 0 秒触发整点播报 =====")
    是否播报 = 取当前秒() == 0
    print("是否播报:", 是否播报)



from typing import Any, Dict, Tuple


def 二维元组按列转字典(元组数据: Tuple[Tuple[Any, ...], ...], 键列索引: int, 值列索引: int) -> Dict[Any, Any]:
    """将二维元组中指定两列转换为字典。

    功能说明:
        - 这个函数用于将二维元组中指定两列转换为字典。
        - 它主要处理“元组里的每一项还是元组”的二维结构，适合表格、记录行、报表数据这类场景。
        - 常用于按列取值、按行统计、转置，或把二维数据整理成更容易继续使用的结果。

    Args:
        元组数据: 由多个子元组组成的二维元组。
        键列索引: 作为字典键的列索引，支持负索引。
        值列索引: 作为字典值的列索引，支持负索引。

    Returns:
        转换成功时返回字典；失败时返回空字典 ``{}``。
    """
    try:
        if not isinstance(元组数据, tuple):
            return {}
        if not isinstance(键列索引, int) or not isinstance(值列索引, int):
            return {}

        结果 = {}
        for 项 in 元组数据:
            if not isinstance(项, tuple):
                return {}
            键 = 项[键列索引]
            值 = 项[值列索引]
            结果[键] = 值
        return 结果
    except Exception:
        return {}


if __name__ == "__main__":
    print("===== 示例1：基础列转字典 =====")
    数据 = (("A001", "张三", 88), ("A002", "李四", 92))
    print("结果:", 二维元组按列转字典(数据, 0, 2))

    print("\n===== 示例2：使用姓名作为键 =====")
    数据 = (("A001", "张三", 88), ("A002", "李四", 92))
    print("结果:", 二维元组按列转字典(数据, 1, 2))

    print("\n===== 示例3：使用负索引 =====")
    数据 = (("A001", "张三", 88), ("A002", "李四", 92))
    print("结果:", 二维元组按列转字典(数据, 0, -1))

    print("\n===== 示例4：列索引越界 =====")
    数据 = (("A001", "张三"), ("A002", "李四"))
    print("结果:", 二维元组按列转字典(数据, 0, 5))

    print("\n===== 示例5：数据结构不合法 =====")
    数据 = (("A001", "张三", 88), "错误项")
    print("结果:", 二维元组按列转字典(数据, 0, 2))

    print("\n===== 示例6：应用场景-把商品编码映射到库存 =====")
    商品数据 = (
        ("SKU001", "鼠标", 150),
        ("SKU002", "键盘", 90),
        ("SKU003", "耳机", 60),
    )
    print("结果:", 二维元组按列转字典(商品数据, 0, 2))






import psutil


def _进程名是否匹配(目标进程名: str | None, 输入进程名: str, 区分大小写: bool) -> bool:
    if not 目标进程名:
        return False
    if 区分大小写:
        return 目标进程名 == 输入进程名
    return 目标进程名.casefold() == 输入进程名.casefold()


def 进程名_是否为唯一实例(进程名: str, 区分大小写: bool = False) -> bool:
    """
    判断指定进程名在系统中是否仅存在一个实例。

    功能说明：
        - 默认不区分大小写，例如 "QQ.exe"、"qq.exe"、"QQ.EXE" 都可匹配。
        - 当“区分大小写”为 True 时，会按原始大小写进行完全匹配。
        - 中文进程名会按原字符串正常比较，不会因大小写兼容逻辑报错。
        - 当匹配数量恰好为 1 时返回 True。
        - 参数无效、未找到、存在多个实例或发生异常时，返回 False。

    Args:
        进程名 (str): 要判断的进程名称。
        区分大小写 (bool): 是否区分大小写，默认为 False。

    Returns:
        bool: 仅存在一个实例返回 True；否则返回 False。
    """
    try:
        if not isinstance(进程名, str):
            return False

        进程名 = 进程名.strip()
        if not 进程名:
            return False

        数量 = 0
        for 进程对象 in psutil.process_iter(['name']):
            if _进程名是否匹配(进程对象.info['name'], 进程名, 区分大小写):
                数量 += 1
                if 数量 > 1:
                    return False
        return 数量 == 1
    except Exception:
        return False



from typing import Any, Dict, List

def 键转列表(数据: Dict[str, Any]) -> List[str]:
    """将字典中的所有键提取为列表。

    功能说明:
        - 这个函数用于将字典中的所有键提取为列表。
        - 它会把原始字典整理成更容易继续使用的结果，适合做数据预处理。
        - 当输入不符合要求时，函数会返回空列表或约定结果，适合直接接到后续代码里继续处理。

    Args:
        数据 (dict): 用于提取键的字典对象。

    Returns:
        list[str]:
        - 成功：包含字典中所有键的列表；
        - 失败：空列表。"""
    try:
        if not isinstance(数据, dict):
            return []

        return [str(键) for 键 in 数据.keys()]
    except Exception:
        return []


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    print("结果:", 键转列表(数据))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    print("结果:", 键转列表(数据))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    print("结果:", 键转列表(数据))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    print("结果:", 键转列表(数据))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    print("结果:", 键转列表(数据))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    print("结果:", 键转列表(数据))
    print("数据:", 数据)



from datetime import datetime


def 取本月第几天(时间字符串: str | None = None) -> int | None:
    """返回指定日期是本月的第几天。

    功能说明:
        - 这个函数用于判断某个日期在本月里排第几天。
        - 支持传入日期，也支持传入完整时间。
        - 不传参数时，默认使用今天。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: ``YYYY-MM-DD`` 或 ``YYYY-MM-DD HH:MM:SS`` 格式的日期时间字符串。

    Returns:
        成功时返回本月第几天；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            return datetime.now().day
        时间字符串 = 时间字符串.strip()
        if len(时间字符串) == 10:
            return datetime.strptime(时间字符串, "%Y-%m-%d").day
        return datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S").day
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：传入普通日期 =====")
    print("结果:", 取本月第几天("2026-03-20"))

    print("\n===== 示例2：传入月初日期 =====")
    print("结果:", 取本月第几天("2026-03-01"))

    print("\n===== 示例3：传入完整时间 =====")
    print("结果:", 取本月第几天("2026-03-20 10:30:45"))

    print("\n===== 示例4：不传参数 =====")
    print("结果:", 取本月第几天())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 取本月第几天("2026/03/20"))

    print("\n===== 示例6：应用场景-显示今天是本月第几天 =====")
    print("结果:", 取本月第几天())



from typing import Any, Dict

def 是否相等_忽略键顺序(
    字典1: Dict[str, Any],
    字典2: Dict[str, Any]
) -> bool:
    """判断两个字典在忽略键顺序的前提下是否结构相等。

    功能说明:
        - 这个函数用于判断两个字典在忽略键顺序的前提下是否结构相等。
        - 它主要返回 True 或 False，适合直接写在 if 判断里控制后续流程。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        字典1 (dict): 第一个待比较字典。
        字典2 (dict): 第二个待比较字典。

    Returns:
        bool:
        True  - 两个字典结构相等；
        False - 不相等或参数非法。"""
    try:
        if not isinstance(字典1, dict):
            return False

        if not isinstance(字典2, dict):
            return False

        return 字典1 == 字典2
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    字典1 = {"a": 1, "b": 2, "c": 3}
    字典2 = {"b": 2, "c": 4, "d": 5}
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)

    print("\n===== 示例2：常见变体 =====")
    字典1 = {"名称": "zfx", "城市": "上海"}
    字典2 = {"城市": "上海", "名称": "zfx"}
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)

    print("\n===== 示例3：边界情况 =====")
    字典1 = {}
    字典2 = {}
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)

    print("\n===== 示例4：异常情况 =====")
    字典1 = []
    字典2 = []
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)

    print("\n===== 示例5：特殊值情况 =====")
    字典1 = {"配置": {"端口": 3306}, "debug": False}
    字典2 = {"配置": {"端口": 3306}, "debug": False}
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    字典1 = {"订单号": "A001", "状态": "待支付", "金额": 99}
    字典2 = {"状态": "待支付"}
    print("结果:", 是否相等_忽略键顺序(字典1, 字典2))
    print("字典1:", 字典1)
    print("字典2:", 字典2)



from datetime import datetime
from typing import Optional


def 解析_中文时间(时间字符串: str) -> Optional[datetime]:
    """把中文格式的时间字符串解析成 ``datetime`` 对象。

    功能说明:
        - 这个函数用于把 ``2026年3月20日15时27分56秒`` 这种中文时间，转换成 Python 里的 ``datetime`` 对象。
        - 转成 ``datetime`` 之后，就更方便继续做时间比较、加减、格式转换。
        - 输入格式必须完整包含年月日时分秒。
        - 解析失败时，函数返回 ``None``。

    Args:
        时间字符串: 中文时间字符串。

    Returns:
        解析成功返回 ``datetime`` 对象；失败时返回 ``None``。
    """
    try:
        return datetime.strptime(时间字符串, "%Y年%m月%d日%H时%M分%S秒")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：解析标准中文时间 =====")
    print("结果:", 解析_中文时间("2026年3月20日15时27分56秒"))

    print("\n===== 示例2：解析个位数月日时分秒 =====")
    print("结果:", 解析_中文时间("2026年3月2日5时6分7秒"))

    print("\n===== 示例3：解析闰年的日期 =====")
    print("结果:", 解析_中文时间("2024年2月29日08时30分00秒"))

    print("\n===== 示例4：缺少秒数字段 =====")
    print("结果:", 解析_中文时间("2026年3月20日15时27分"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 解析_中文时间("2026年2月30日15时27分56秒"))

    print("\n===== 示例6：应用场景-把中文合同时间转成 datetime 后继续处理 =====")
    合同时间 = "2026年4月1日09时00分00秒"
    解析结果 = 解析_中文时间(合同时间)
    print("解析结果:", 解析结果)



from datetime import datetime


def 取星座(日期字符串: str) -> str | None:
    """根据日期返回对应的星座。

    功能说明:
        - 这个函数用于把日期转换成常见的十二星座名称。
        - 输入格式是 ``YYYY-MM-DD``。
        - 函数按公历日期区间判断星座。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        日期字符串: 日期字符串。

    Returns:
        成功时返回星座名称；失败时返回 ``None``。
    """
    try:
        日期对象 = datetime.strptime(日期字符串.strip(), "%Y-%m-%d")
        月 = 日期对象.month
        日 = 日期对象.day

        if (月 == 3 and 日 >= 21) or (月 == 4 and 日 <= 19):
            return "白羊座"
        if (月 == 4 and 日 >= 20) or (月 == 5 and 日 <= 20):
            return "金牛座"
        if (月 == 5 and 日 >= 21) or (月 == 6 and 日 <= 21):
            return "双子座"
        if (月 == 6 and 日 >= 22) or (月 == 7 and 日 <= 22):
            return "巨蟹座"
        if (月 == 7 and 日 >= 23) or (月 == 8 and 日 <= 22):
            return "狮子座"
        if (月 == 8 and 日 >= 23) or (月 == 9 and 日 <= 22):
            return "处女座"
        if (月 == 9 and 日 >= 23) or (月 == 10 and 日 <= 23):
            return "天秤座"
        if (月 == 10 and 日 >= 24) or (月 == 11 and 日 <= 22):
            return "天蝎座"
        if (月 == 11 and 日 >= 23) or (月 == 12 and 日 <= 21):
            return "射手座"
        if (月 == 12 and 日 >= 22) or (月 == 1 and 日 <= 19):
            return "摩羯座"
        if (月 == 1 and 日 >= 20) or (月 == 2 and 日 <= 18):
            return "水瓶座"
        return "双鱼座"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：白羊座日期 =====")
    print("结果:", 取星座("2026-03-21"))

    print("\n===== 示例2：摩羯座日期 =====")
    print("结果:", 取星座("2026-01-10"))

    print("\n===== 示例3：双鱼座日期 =====")
    print("结果:", 取星座("2026-02-25"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 取星座("2026/03/21"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 取星座("2026-02-30"))

    print("\n===== 示例6：应用场景-根据生日展示用户星座 =====")
    print("用户星座:", 取星座("1998-06-18"))



from datetime import datetime


def 是否周末(时间字符串: str | None = None) -> bool:
    """判断某个时间是不是周末。

    功能说明:
        - 这个函数用于判断某个日期是不是星期六或星期日。
        - 你可以传入完整时间字符串，也可以不传参数直接判断今天。
        - 周末指星期六和星期日。
        - 输入格式不正确时，函数返回 ``False``。

    Args:
        时间字符串: 要判断的时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``；不传时默认判断当前时间。

    Returns:
        是周末返回 ``True``，否则返回 ``False``。
    """
    try:
        if 时间字符串 is None:
            时间对象 = datetime.now()
        else:
            时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return 时间对象.weekday() >= 5
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：判断周六 =====")
    print("结果:", 是否周末("2026-03-21 10:00:00"))

    print("\n===== 示例2：判断周日 =====")
    print("结果:", 是否周末("2026-03-22 10:00:00"))

    print("\n===== 示例3：判断工作日 =====")
    print("结果:", 是否周末("2026-03-20 10:00:00"))

    print("\n===== 示例4：不传参数，判断今天 =====")
    print("结果:", 是否周末())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 是否周末("2026/03/21"))

    print("\n===== 示例6：应用场景-决定是否显示周末值班提示 =====")
    print("是否显示值班提示:", 是否周末("2026-03-22 09:00:00"))



from typing import Any, Tuple


def 取前N项(元组数据: Tuple[Any, ...], 数量: int):
    """返回元组前 N 项。

    功能说明:
        - 这个函数用于返回元组前 N 项。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    Args:
        元组数据: 待处理的元组。
        数量: 需要截取的成员数量。

    Returns:
        成功时返回新元组；失败时返回空元组 ``()``。
    """
    try:
        if not isinstance(元组数据, tuple) or not isinstance(数量, int) or 数量 < 0:
            return ()
        return 元组数据[:数量]
    except Exception:
        return ()


if __name__ == "__main__":
    print("===== 示例1：取前3项 =====")
    数据 = (1, 2, 3, 4, 5)
    print("结果:", 取前N项(数据, 3))

    print("\n===== 示例2：数量超过长度 =====")
    数据 = (1, 2)
    print("结果:", 取前N项(数据, 10))

    print("\n===== 示例3：数量非法 =====")
    数据 = (1, 2, 3)
    print("结果:", 取前N项(数据, -1))

    print("\n===== 示例4：数量为0 =====")
    数据 = (1, 2, 3)
    print("结果:", 取前N项(数据, 0))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取前N项(数据, 3))

    print("\n===== 示例6：应用场景-取排行榜前3名 =====")
    排行榜 = ("张三", "李四", "王五", "赵六", "钱七")
    print("结果:", 取前N项(排行榜, 3))






from datetime import datetime


def 获取相差年数(时间1: str, 时间2: str) -> int | None:
    """计算两个时间相差多少个完整年。

    功能说明:
        - 这个函数用于计算两个标准时间之间相差多少个“完整年”。
        - 返回结果保留正负号，第二个时间更晚时返回正数。
        - 如果还没满一年，就不会进位成 1。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间1: 起始时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。
        时间2: 结束时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。

    Returns:
        成功时返回完整年数差；失败时返回 ``None``。
    """
    try:
        t1 = datetime.strptime(时间1.strip(), "%Y-%m-%d %H:%M:%S")
        t2 = datetime.strptime(时间2.strip(), "%Y-%m-%d %H:%M:%S")

        符号 = 1
        if t2 < t1:
            t1, t2 = t2, t1
            符号 = -1

        年数差 = t2.year - t1.year
        if (t2.month, t2.day, t2.hour, t2.minute, t2.second) < (t1.month, t1.day, t1.hour, t1.minute, t1.second):
            年数差 -= 1
        return 年数差 * 符号
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：刚好相差 1 个完整年 =====")
    print("结果:", 获取相差年数("2025-03-20 10:00:00", "2026-03-20 10:00:00"))

    print("\n===== 示例2：不足 1 个完整年 =====")
    print("结果:", 获取相差年数("2025-03-20 10:00:00", "2026-03-19 10:00:00"))

    print("\n===== 示例3：相差多年 =====")
    print("结果:", 获取相差年数("2020-01-01 00:00:00", "2026-01-01 00:00:00"))

    print("\n===== 示例4：第二个时间更早 =====")
    print("结果:", 获取相差年数("2026-01-01 00:00:00", "2020-01-01 00:00:00"))

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 获取相差年数("2025/03/20", "2026-03-20 10:00:00"))

    print("\n===== 示例6：应用场景-计算员工工龄满了几年 =====")
    print("结果:", 获取相差年数("2020-05-10 09:00:00", "2026-05-10 09:00:00"))



from typing import Any, Tuple


def 取全部众数(元组数据: Tuple[Any, ...]):
    """返回元组中的全部众数。

    功能说明:
        - 这个函数用于返回元组中的全部众数。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    说明:
        - 返回所有出现次数并列最高的成员。
        - 返回顺序按成员首次出现顺序保留。

    Args:
        元组数据: 待统计的元组。

    Returns:
        成功时返回 ``(众数元组, True)``；失败时返回 ``((), False)``。
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return (), False

        频率列表 = []
        for 元素 in 元组数据:
            已找到 = False
            for 项 in 频率列表:
                if 项[0] == 元素:
                    项[1] += 1
                    已找到 = True
                    break
            if not 已找到:
                频率列表.append([元素, 1])

        最大次数 = max(次数 for _, 次数 in 频率列表)
        结果 = tuple(元素 for 元素, 次数 in 频率列表 if 次数 == 最大次数)
        return 结果, True
    except Exception:
        return (), False


if __name__ == "__main__":
    print("===== 示例1：单一众数 =====")
    数据 = (1, 2, 2, 3, 2, 4)
    print("结果:", 取全部众数(数据))

    print("\n===== 示例2：多个并列众数 =====")
    数据 = ("a", "b", "a", "b", "c")
    print("结果:", 取全部众数(数据))

    print("\n===== 示例3：全部唯一时全部都是众数 =====")
    数据 = (1, 2, 3)
    print("结果:", 取全部众数(数据))

    print("\n===== 示例4：单成员元组 =====")
    数据 = ("唯一",)
    print("结果:", 取全部众数(数据))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取全部众数(数据))

    print("\n===== 示例6：应用场景-找出最常出现的异常码集合 =====")
    异常码 = ("E01", "E02", "E01", "E03", "E02", "E04")
    print("结果:", 取全部众数(异常码))






from typing import Any, Tuple


def 取后半部分(元组数据: Tuple[Any, ...]):
    """返回元组的后半部分。

    功能说明:
        - 这个函数用于返回元组的后半部分。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    Args:
        元组数据: 待处理的元组。

    Returns:
        成功时返回后半部分元组；失败时返回空元组 ``()``。
    """
    try:
        if not isinstance(元组数据, tuple):
            return ()
        分界点 = (len(元组数据) + 1) // 2
        return 元组数据[分界点:]
    except Exception:
        return ()


if __name__ == "__main__":
    print("===== 示例1：偶数长度后半部分 =====")
    数据 = (1, 2, 3, 4)
    print("结果:", 取后半部分(数据))

    print("\n===== 示例2：奇数长度后半部分 =====")
    数据 = (1, 2, 3, 4, 5)
    print("结果:", 取后半部分(数据))

    print("\n===== 示例3：单成员元组 =====")
    数据 = ("唯一",)
    print("结果:", 取后半部分(数据))

    print("\n===== 示例4：空元组 =====")
    数据 = ()
    print("结果:", 取后半部分(数据))

    print("\n===== 示例5：数据不是元组 =====")
    数据 = [1, 2, 3]
    print("结果:", 取后半部分(数据))

    print("\n===== 示例6：应用场景-取下半天的预约记录 =====")
    预约列表 = ("9点", "10点", "11点", "13点", "14点")
    print("结果:", 取后半部分(预约列表))






from .ISO格式转标准时间 import ISO格式转标准时间
from .取一周第几天 import 取一周第几天
from .取上周开始时间 import 取上周开始时间
from .取上周结束时间 import 取上周结束时间
from .取上月开始时间 import 取上月开始时间
from .取上月结束时间 import 取上月结束时间
from .取下周开始时间 import 取下周开始时间
from .取下周结束时间 import 取下周结束时间
from .取下月开始时间 import 取下月开始时间
from .取下月结束时间 import 取下月结束时间
from .取前N天日期 import 取前N天日期
from .取后N天日期 import 取后N天日期
from .取年龄 import 取年龄
from .取当前分钟 import 取当前分钟
from .取当前小时 import 取当前小时
from .取当前年份 import 取当前年份
from .取当前年月 import 取当前年月
from .取当前年月日时分秒 import 取当前年月日时分秒
from .取当前日 import 取当前日
from .取当前日期 import 取当前日期
from .取当前时分 import 取当前时分
from .取当前时间 import 取当前时间
from .取当前月份 import 取当前月份
from .取当前秒 import 取当前秒
from .取明天日期 import 取明天日期
from .取星座 import 取星座
from .取星期几 import 取星期几
from .取昨天日期 import 取昨天日期
from .取月份天数 import 取月份天数
from .取本周开始时间 import 取本周开始时间
from .取本周结束时间 import 取本周结束时间
from .取本季度开始时间 import 取本季度开始时间
from .取本季度结束时间 import 取本季度结束时间
from .取本年开始时间 import 取本年开始时间
from .取本年第几天 import 取本年第几天
from .取本年结束时间 import 取本年结束时间
from .取本月开始时间 import 取本月开始时间
from .取本月第几天 import 取本月第几天
from .取本月结束时间 import 取本月结束时间
from .取某天开始时间 import 取某天开始时间
from .取某天结束时间 import 取某天结束时间
from .取某季度开始时间 import 取某季度开始时间
from .取某季度结束时间 import 取某季度结束时间
from .取某年天数 import 取某年天数
from .取某年开始时间 import 取某年开始时间
from .取某年结束时间 import 取某年结束时间
from .取某月天数 import 取某月天数
from .取生肖 import 取生肖
from .取系统时间 import 取系统时间
from .取系统时间戳 import 取系统时间戳
from .定时放行 import 定时放行
from .日期转年月日 import 日期转年月日
from .日期转星期几 import 日期转星期几
from .时间加分钟 import 时间加分钟
from .时间加天数 import 时间加天数
from .时间加小时 import 时间加小时
from .时间去掉秒 import 时间去掉秒
from .时间字符串转秒数 import 时间字符串转秒数
from .时间戳转换为时间 import 时间戳转换为时间
from .时间计算 import 时间计算
from .时间转换为时间戳 import 时间转换为时间戳
from .时间转时分秒 import 时间转时分秒
from .是否今天 import 是否今天
from .是否周末 import 是否周末
from .是否工作日 import 是否工作日
from .是否明天 import 是否明天
from .是否昨天 import 是否昨天
from .是否月初 import 是否月初
from .是否月末 import 是否月末
from .是否本周 import 是否本周
from .是否本年 import 是否本年
from .是否本月 import 是否本月
from .是否闰年 import 是否闰年
from .标准时间转ISO格式 import 标准时间转ISO格式
from .标准时间转中文时间 import 标准时间转中文时间
from .秒数转时间字符串 import 秒数转时间字符串
from .获取今日剩余时长 import 获取今日剩余时长
from .获取时间间隔 import 获取时间间隔
from .获取时间间隔秒数 import 获取时间间隔秒数
from .获取相差分钟数 import 获取相差分钟数
from .获取相差天数 import 获取相差天数
from .获取相差小时数 import 获取相差小时数
from .获取相差年数 import 获取相差年数
from .获取相差月数 import 获取相差月数
from .补全日期为开始时间 import 补全日期为开始时间
from .补全日期为结束时间 import 补全日期为结束时间
from .解析_中文时间 import 解析_中文时间
from .距今分钟数 import 距今分钟数
from .距今天数 import 距今天数
from .距今小时数 import 距今小时数
from .距今秒数 import 距今秒数
from .验证时间格式 import 验证时间格式



from typing import Any, Dict

def 确保包含键(
    数据: Dict[str, Any],
    键: Any,
    默认值: Any = None
) -> bool:
    """确保字典中包含指定键；若键不存在，则写入默认值。

    功能说明:
        - 这个函数用于确保字典中包含指定键；若键不存在，则写入默认值。
        - 它主要返回 True 或 False，适合直接写在 if 判断里控制后续流程。
        - 当输入不符合要求时，函数会直接返回 False，方便你快速判断这次操作有没有成功。

    Args:
        数据 (dict): 目标字典对象。
        键: 需要确保存在的键，内部将转换为字符串。
        默认值: 当键不存在时写入的默认值。

    Returns:
        bool:
        True  - 键不存在且已成功写入默认值；
        False - 键已存在、数据非法或发生异常。"""
    try:
        if not isinstance(数据, dict):
            return False

        键名 = str(键)

        if 键名 in 数据:
            return False

        数据[键名] = 默认值
        return True
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    键 = "名称"
    默认值 = "默认值"
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    键 = "name"
    默认值 = "未找到"
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键 = "不存在"
    默认值 = "空"
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键 = "名称"
    默认值 = "失败"
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    键 = "备注"
    默认值 = 0
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    键 = "状态"
    默认值 = "未知状态"
    print("结果:", 确保包含键(数据, 键, 默认值))
    print("数据:", 数据)



def 取生肖(年份: int) -> str | None:
    """根据年份返回对应的生肖。

    功能说明:
        - 这个函数用于把年份转换成十二生肖。
        - 传入公历年份后，会返回 ``鼠``、``牛``、``虎`` 这样的生肖名称。
        - 这里只按年份判断，不区分农历新年前后的细节。
        - 年份不合法时，函数返回 ``None``。

    Args:
        年份: 要查询的年份。

    Returns:
        成功时返回生肖名称；失败时返回 ``None``。
    """
    try:
        年份 = int(年份)
        if 年份 <= 0:
            return None
        生肖列表 = ["鼠", "牛", "虎", "兔", "龙", "蛇", "马", "羊", "猴", "鸡", "狗", "猪"]
        return 生肖列表[(年份 - 4) % 12]
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：查询 2024 年生肖 =====")
    print("结果:", 取生肖(2024))

    print("\n===== 示例2：查询 2026 年生肖 =====")
    print("结果:", 取生肖(2026))

    print("\n===== 示例3：传入字符串年份 =====")
    print("结果:", 取生肖("2000"))

    print("\n===== 示例4：年份为 0 =====")
    print("结果:", 取生肖(0))

    print("\n===== 示例5：输入非法内容 =====")
    print("结果:", 取生肖("二零二六"))

    print("\n===== 示例6：应用场景-根据出生年份展示用户生肖 =====")
    用户出生年 = 1991
    print("用户生肖:", 取生肖(用户出生年))



from typing import Any, Tuple


def 取极差(元组数据: Tuple[Any, ...]):
    """返回元组数值成员的极差。

    功能说明:
        - 这个函数用于返回元组数值成员的极差。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    Args:
        元组数据: 仅包含可比较数值的元组。

    Returns:
        成功时返回极差；失败时返回 ``None``。
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return None
        return max(元组数据) - min(元组数据)
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础极差 =====")
    数据 = (10, 30, 20, 50)
    print("结果:", 取极差(数据))

    print("\n===== 示例2：包含负数 =====")
    数据 = (-5, 10, 20)
    print("结果:", 取极差(数据))

    print("\n===== 示例3：单成员元组 =====")
    数据 = (99,)
    print("结果:", 取极差(数据))

    print("\n===== 示例4：空元组 =====")
    数据 = ()
    print("结果:", 取极差(数据))

    print("\n===== 示例5：包含非数字 =====")
    数据 = (10, "20", 30)
    print("结果:", 取极差(数据))

    print("\n===== 示例6：应用场景-分析本周波动范围 =====")
    日销售额 = (1200, 1880, 1560, 2100, 1750)
    print("结果:", 取极差(日销售额))






from datetime import datetime


def 取系统时间():
    """返回当前系统时间字符串。

    功能说明:
        - 这个函数用于获取电脑当前的系统时间，格式固定为 ``YYYY-MM-DD HH:MM:SS``。
        - 适合直接拿来写日志、做时间记录、生成报表时间。
        - 如果极少数情况下获取失败，函数会返回 ``False``。

    Returns:
        成功时返回当前系统时间字符串；失败时返回 ``False``。
    """
    try:
        系统时间 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        return 系统时间
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：直接获取当前系统时间 =====")
    print("结果:", 取系统时间())

    print("\n===== 示例2：查看返回值类型 =====")
    当前时间 = 取系统时间()
    print("结果:", 当前时间, "类型:", type(当前时间).__name__)

    print("\n===== 示例3：用于记录程序启动时间 =====")
    启动时间 = 取系统时间()
    print("程序启动时间:", 启动时间)

    print("\n===== 示例4：用于生成带时间的日志内容 =====")
    日志内容 = f"[{取系统时间()}] 开始同步订单"
    print("结果:", 日志内容)

    print("\n===== 示例5：连续调用两次看看格式是否一致 =====")
    print("结果1:", 取系统时间())
    print("结果2:", 取系统时间())

    print("\n===== 示例6：应用场景-给导出文件补上生成时间 =====")
    导出信息 = {
        "file_name": "销售明细.xlsx",
        "created_at": 取系统时间(),
    }
    print("导出信息:", 导出信息)



from datetime import datetime


def 取当前月份() -> int:
    """返回当前系统月份。

    功能说明:
        - 这个函数用于获取当前的月份。
        - 返回结果是整数，范围通常是 ``1`` 到 ``12``。
        - 适合做月份判断、月报筛选和月份计算前的取值。

    Returns:
        返回当前月份，例如 ``3``。
    """
    return datetime.now().month


if __name__ == "__main__":
    print("===== 示例1：直接获取当前月份 =====")
    print("结果:", 取当前月份())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取当前月份()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：判断当前是否在上半年 =====")
    print("结果:", 取当前月份() <= 6)

    print("\n===== 示例4：用于拼接月份标题 =====")
    标题 = f"{取当前月份()}月数据"
    print("结果:", 标题)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取当前月份())
    print("结果2:", 取当前月份())

    print("\n===== 示例6：应用场景-生成当月报表文件名 =====")
    文件名 = f"{取当前月份()}月库存报表.xlsx"
    print("文件名:", 文件名)



from datetime import datetime


def 距今分钟数(时间字符串: str) -> float | None:
    """计算某个时间距离现在相差多少分钟。

    功能说明:
        - 这个函数用于比较目标时间和当前系统时间之间的分钟差。
        - 目标时间在未来时返回正数，已经过去时返回负数。
        - 适合做预约倒计时、超时提醒和剩余时间判断。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: 目标时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``。

    Returns:
        成功时返回分钟差；失败时返回 ``None``。
    """
    try:
        给定时间 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        当前时间 = datetime.now()
        return (给定时间 - 当前时间).total_seconds() / 60
    except Exception:
        return None


if __name__ == "__main__":
    from datetime import timedelta

    print("===== 示例1：目标时间在未来 =====")
    未来时间 = (datetime.now() + timedelta(minutes=30)).strftime("%Y-%m-%d %H:%M:%S")
    print("结果:", 距今分钟数(未来时间))

    print("\n===== 示例2：目标时间在过去 =====")
    过去时间 = (datetime.now() - timedelta(minutes=30)).strftime("%Y-%m-%d %H:%M:%S")
    print("结果:", 距今分钟数(过去时间))

    print("\n===== 示例3：目标时间就是现在附近 =====")
    当前时间 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    print("结果:", 距今分钟数(当前时间))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 距今分钟数("2026/03/20"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 距今分钟数(""))

    print("\n===== 示例6：应用场景-查看会议开始前还剩多少分钟 =====")
    会议时间 = (datetime.now() + timedelta(minutes=15)).strftime("%Y-%m-%d %H:%M:%S")
    print("结果:", 距今分钟数(会议时间))



from datetime import datetime


def 取当前年月日时分秒() -> str:
    """返回当前完整时间字符串。

    功能说明:
        - 这个函数用于一次性获取当前的年月日时分秒。
        - 返回格式固定为 ``YYYY-MM-DD HH:MM:SS``。
        - 适合记录完整日志时间、生成详细时间标签或做时间展示。

    Returns:
        返回当前完整时间字符串，例如 ``2026-03-20 16:25:30``。
    """
    return datetime.now().strftime("%Y-%m-%d %H:%M:%S")


if __name__ == "__main__":
    print("===== 示例1：直接获取当前年月日时分秒 =====")
    print("结果:", 取当前年月日时分秒())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取当前年月日时分秒()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：用于记录完整日志时间 =====")
    日志 = f"[{取当前年月日时分秒()}] 开始执行任务"
    print("结果:", 日志)

    print("\n===== 示例4：用于页面显示当前完整时间 =====")
    标题 = f"当前时间：{取当前年月日时分秒()}"
    print("结果:", 标题)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取当前年月日时分秒())
    print("结果2:", 取当前年月日时分秒())

    print("\n===== 示例6：应用场景-给导出记录补上完整创建时间 =====")
    记录 = {"file": "report.xlsx", "created_at": 取当前年月日时分秒()}
    print("记录:", 记录)



from typing import Any, Tuple


def 取众数(元组数据: Tuple[Any, ...]):
    """返回元组中的众数。

    功能说明:
        - 这个函数用于返回元组中的众数。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    Args:
        元组数据: 待统计的元组。

    Returns:
        成功时返回 ``(众数, True)``；失败时返回 ``(None, False)``。
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return None, False

        频率列表 = []
        for 元素 in 元组数据:
            已找到 = False
            for 项 in 频率列表:
                if 项[0] == 元素:
                    项[1] += 1
                    已找到 = True
                    break
            if not 已找到:
                频率列表.append([元素, 1])

        众数 = 频率列表[0][0]
        最大次数 = 频率列表[0][1]
        for 元素, 次数 in 频率列表[1:]:
            if 次数 > 最大次数:
                众数 = 元素
                最大次数 = 次数
        return 众数, True
    except Exception:
        return None, False


if __name__ == "__main__":
    print("===== 示例1：基础众数 =====")
    数据 = (1, 2, 2, 3, 2, 4)
    print("结果:", 取众数(数据))

    print("\n===== 示例2：字符串众数 =====")
    数据 = ("a", "b", "a", "c", "a")
    print("结果:", 取众数(数据))

    print("\n===== 示例3：并列时返回先达到最高频的成员 =====")
    数据 = ("a", "b", "a", "b")
    print("结果:", 取众数(数据))

    print("\n===== 示例4：单成员元组 =====")
    数据 = ("唯一",)
    print("结果:", 取众数(数据))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取众数(数据))

    print("\n===== 示例6：应用场景-统计最常出现的访问来源 =====")
    来源列表 = ("百度", "知乎", "百度", "官网", "百度", "公众号")
    print("结果:", 取众数(来源列表))






from datetime import datetime, timedelta


def 取后N天日期(天数: int) -> str | None:
    """返回当前日期往后推 N 天后的日期。

    功能说明:
        - 这个函数用于计算几天后是哪一天。
        - 传入 ``3`` 就表示返回 3 天后的日期。
        - 返回格式固定为 ``YYYY-MM-DD``。
        - 如果天数不是整数，函数返回 ``None``。

    Args:
        天数: 要往后推的天数。

    Returns:
        成功时返回日期字符串；失败时返回 ``None``。
    """
    try:
        return (datetime.now() + timedelta(days=天数)).strftime("%Y-%m-%d")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：取 3 天后的日期 =====")
    print("结果:", 取后N天日期(3))

    print("\n===== 示例2：取 0 天后的日期，也就是今天 =====")
    print("结果:", 取后N天日期(0))

    print("\n===== 示例3：取 30 天后的日期 =====")
    print("结果:", 取后N天日期(30))

    print("\n===== 示例4：传入负数，相当于往前推 =====")
    print("结果:", 取后N天日期(-2))

    print("\n===== 示例5：天数不是整数 =====")
    print("结果:", 取后N天日期("3"))

    print("\n===== 示例6：应用场景-计算 7 天后的回访日期 =====")
    回访日期 = 取后N天日期(7)
    print("回访日期:", 回访日期)



from datetime import datetime


def 取某天结束时间(时间字符串: str | None = None) -> str | None:
    """返回某一天的结束时间。

    功能说明:
        - 这个函数用于把某个日期统一补成当天最后一秒，也就是 ``23:59:59``。
        - 适合按天查询数据时直接生成结束时间。
        - 可以传日期，也可以传完整时间，函数只保留日期部分。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: ``YYYY-MM-DD`` 或 ``YYYY-MM-DD HH:MM:SS`` 格式的日期时间字符串。

    Returns:
        成功时返回当天结束时间字符串；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            日期对象 = datetime.now().date()
        else:
            时间字符串 = 时间字符串.strip()
            if len(时间字符串) == 10:
                日期对象 = datetime.strptime(时间字符串, "%Y-%m-%d").date()
            else:
                日期对象 = datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S").date()

        return f"{日期对象} 23:59:59"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：传入日期，取当天结束时间 =====")
    print("结果:", 取某天结束时间("2026-03-20"))

    print("\n===== 示例2：传入完整时间，取当天结束时间 =====")
    print("结果:", 取某天结束时间("2026-03-20 18:30:45"))

    print("\n===== 示例3：不传参数，取今天结束时间 =====")
    print("结果:", 取某天结束时间())

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 取某天结束时间("2026/03/20"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 取某天结束时间("2026-02-30"))

    print("\n===== 示例6：应用场景-生成当天订单查询终点 =====")
    查询日期 = "2026-05-08 21:16:30"
    print("查询结束:", 取某天结束时间(查询日期))



from datetime import datetime


def 取一周第几天(时间字符串: str | None = None) -> int | None:
    """返回指定日期是一周里的第几天。

    功能说明:
        - 这个函数用于判断某个日期在一周中排第几天。
        - 返回规则是周一为 ``1``，周日为 ``7``。
        - 支持传入完整时间，也可以不传参数直接判断今天。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: 时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``；不传时默认当前时间。

    Returns:
        成功时返回一周中的序号；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            return datetime.now().weekday() + 1
        时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return 时间对象.weekday() + 1
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：周一是一周第几天 =====")
    print("结果:", 取一周第几天("2026-03-23 10:00:00"))

    print("\n===== 示例2：周五是一周第几天 =====")
    print("结果:", 取一周第几天("2026-03-20 10:00:00"))

    print("\n===== 示例3：周日是一周第几天 =====")
    print("结果:", 取一周第几天("2026-03-22 10:00:00"))

    print("\n===== 示例4：不传参数 =====")
    print("结果:", 取一周第几天())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 取一周第几天("2026/03/22"))

    print("\n===== 示例6：应用场景-根据周几决定排班序号 =====")
    print("排班序号:", 取一周第几天("2026-03-24 09:00:00"))



from __future__ import annotations

from typing import Any, Dict, Iterable, List, Sequence, Union, Optional


_路径类型 = Union[str, Sequence[Any]]

def 取值_路径(
    数据: Any,
    键路径: _路径类型,
    默认值: Any = None,
    分隔符: str = ".",
    键转字符串: bool = True,
) -> Any:
    """根据“键路径”从嵌套结构中安全取值（dict/list 混合），失败返回默认值。

    功能说明:
        - 这个函数用于根据“键路径”从嵌套结构中安全取值（dict/list 混合），失败返回默认值。
        - 它适合处理多层嵌套字典或字典与列表混合的数据，省得自己一层一层判断。
        - 当输入不符合要求时，函数会返回约定好的兜底结果，避免程序因为异常中断。

    Args:
        数据 (Any): 任意输入对象，通常为 dict/list 的嵌套结构。
        键路径 (str | Sequence[Any]): 路径字符串或路径序列。
        默认值 (Any): 失败时返回值，默认 None。
        分隔符 (str): 当键路径为字符串时的分隔符，默认 "."。
        键转字符串 (bool): 当走 dict 取值时，是否将键统一转换为 str。默认 True。

    Returns:
        Any:
        - 成功：返回路径命中的值
        - 失败：返回默认值"""
    try:
        # 1) 归一化路径
        if isinstance(键路径, str):
            if 键路径 == "":
                return 默认值
            路径列表: List[Any] = 键路径.split(分隔符)
        elif isinstance(键路径, (list, tuple)):
            if len(键路径) == 0:
                return 默认值
            路径列表 = list(键路径)
        else:
            return 默认值

        当前 = 数据

        # 2) 逐段向下取值
        for 段 in 路径列表:
            if isinstance(当前, dict):
                键 = str(段) if 键转字符串 else 段
                if 键 in 当前:
                    当前 = 当前[键]
                else:
                    return 默认值

            elif isinstance(当前, (list, tuple)):
                # 允许 "0" / 0 两种写法
                try:
                    索引 = 段 if isinstance(段, int) else int(str(段))
                except Exception:
                    return 默认值

                if 0 <= 索引 < len(当前):
                    当前 = 当前[索引]
                else:
                    return 默认值
            else:
                return 默认值

        return 当前

    except Exception:
        return 默认值


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"用户": {"信息": [{"城市": "上海", "年龄": 18}]}}
    键路径 = "用户.信息.0.城市"
    默认值 = "默认值"
    分隔符 = "."
    键转字符串 = True
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"用户": {"信息": [{"城市": "北京"}]}}
    键路径 = ["用户", "信息", 0, "城市"]
    默认值 = "未找到"
    分隔符 = "."
    键转字符串 = True
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键路径 = ""
    默认值 = "空"
    分隔符 = "."
    键转字符串 = True
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键路径 = "用户.信息.5.城市"
    默认值 = "失败"
    分隔符 = "."
    键转字符串 = True
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"用户": {"信息": [{"城市": None, "标签": ""}]}}
    键路径 = "用户.信息.0.标签"
    默认值 = 0
    分隔符 = "."
    键转字符串 = False
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单": {"收货信息": [{"城市": "杭州", "联系人": "张三"}]}}
    键路径 = "订单.收货信息.0.联系人"
    默认值 = "未知状态"
    分隔符 = "."
    键转字符串 = True
    print("结果:", 取值_路径(数据, 键路径, 默认值, 分隔符, 键转字符串))
    print("数据:", 数据)



from typing import Any, Dict, Tuple, Type, Union


_期望类型 = Union[Type[Any], Tuple[Type[Any], ...]]

def 取值_类型安全(
    数据: Dict[str, Any],
    键: Any,
    期望类型: _期望类型,
    默认值: Any = None
) -> Any:
    """安全取值，并校验结果是否符合期望类型；不符合则返回默认值。

    功能说明:
        - 这个函数用于安全取值，并校验结果是否符合期望类型；不符合则返回默认值。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回约定好的兜底结果，避免程序因为异常中断。

    Args:
        数据 (dict): 用于取值的字典对象。
        键: 要读取的键，内部将转换为字符串。
        期望类型 (type | tuple[type, ...]): 允许的目标类型。
        - 单类型示例： str
        - 多类型示例： (int, float)
        默认值: 当键不存在或类型不匹配时返回的值，默认为 None。

    Returns:
        Any:
        - 成功：返回符合期望类型的原始值；
        - 失败：返回默认值。"""
    try:
        if not isinstance(数据, dict):
            return 默认值

        键名 = str(键)
        if 键名 not in 数据:
            return 默认值

        值 = 数据[键名]
        if isinstance(值, 期望类型):
            return 值

        return 默认值
    except Exception:
        return 默认值


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    键 = "名称"
    期望类型 = str
    默认值 = "默认值"
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    键 = "name"
    期望类型 = (str, int)
    默认值 = "未找到"
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    键 = "不存在"
    期望类型 = str
    默认值 = "空"
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    键 = "名称"
    期望类型 = str
    默认值 = "失败"
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    键 = "备注"
    期望类型 = (str, type(None))
    默认值 = 0
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    键 = "状态"
    期望类型 = str
    默认值 = "未知状态"
    print("结果:", 取值_类型安全(数据, 键, 期望类型, 默认值))
    print("数据:", 数据)



from datetime import datetime


def 是否本年(时间字符串: str) -> bool:
    """判断某个时间是不是在本年内。

    功能说明:
        - 这个函数用于判断传入时间的年份是否和当前年份相同。
        - 输入内容必须是 ``YYYY-MM-DD HH:MM:SS`` 格式。
        - 只比较年份，不比较月份和日。
        - 输入格式不正确时，函数返回 ``False``。

    Args:
        时间字符串: 要判断的时间字符串。

    Returns:
        属于本年返回 ``True``，否则返回 ``False``。
    """
    try:
        输入时间 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        当前时间 = datetime.now()
        return 输入时间.year == 当前时间.year
    except Exception:
        return False


if __name__ == "__main__":
    今天时间 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")

    print("===== 示例1：传入今天的时间 =====")
    print("结果:", 是否本年(今天时间))

    print("\n===== 示例2：传入本年其他月份 =====")
    print("结果:", 是否本年(datetime.now().strftime("%Y-01-01 08:00:00")))

    print("\n===== 示例3：传入其他年份时间 =====")
    print("结果:", 是否本年("2020-01-01 12:00:00"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 是否本年("2026/03/20"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 是否本年(""))

    print("\n===== 示例6：应用场景-筛选本年成交记录 =====")
    print("是否本年成交:", 是否本年(今天时间))



from datetime import datetime, timedelta


def 取昨天日期() -> str:
    """返回昨天的日期字符串。

    功能说明:
        - 这个函数用于获取昨天的日期。
        - 返回格式固定为 ``YYYY-MM-DD``。
        - 适合按天查询昨天数据、生成昨天报表和写时间标签。

    Returns:
        返回昨天的日期字符串。
    """
    return (datetime.now() - timedelta(days=1)).strftime("%Y-%m-%d")


if __name__ == "__main__":
    print("===== 示例1：直接获取昨天日期 =====")
    print("结果:", 取昨天日期())

    print("\n===== 示例2：查看返回值类型 =====")
    结果 = 取昨天日期()
    print("结果:", 结果, "类型:", type(结果).__name__)

    print("\n===== 示例3：用于查询昨天订单 =====")
    条件 = {"date": 取昨天日期()}
    print("结果:", 条件)

    print("\n===== 示例4：用于生成昨天报表文件名 =====")
    文件名 = f"sales_{取昨天日期()}.xlsx"
    print("结果:", 文件名)

    print("\n===== 示例5：连续调用两次 =====")
    print("结果1:", 取昨天日期())
    print("结果2:", 取昨天日期())

    print("\n===== 示例6：应用场景-按昨天日期统计登录人数 =====")
    查询日期 = 取昨天日期()
    print("准备统计日期:", 查询日期)



from datetime import datetime


def ISO格式转标准时间(时间字符串: str) -> str | None:
    """把 ISO 格式时间字符串转成常见的标准时间字符串。

    功能说明:
        - 这个函数用于把接口、日志里常见的 ISO 时间字符串，转换成 ``YYYY-MM-DD HH:MM:SS`` 这种更容易阅读的格式。
        - 它可以处理带 ``T`` 的时间，也可以处理末尾带 ``Z`` 或时区偏移量的时间。
        - 如果传入的内容不是合法时间，函数不会报错，而是返回 ``None``。

    Args:
        时间字符串: ISO 格式的时间字符串。

    Returns:
        成功时返回标准时间字符串；转换失败时返回 ``None``。
    """
    try:
        dt = datetime.fromisoformat(时间字符串.replace("Z", "+00:00"))
        return dt.strftime("%Y-%m-%d %H:%M:%S")
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：把带 Z 的 ISO 时间转成标准时间 =====")
    print("结果:", ISO格式转标准时间("2025-11-13T06:50:00Z"))

    print("\n===== 示例2：把带时区偏移的 ISO 时间转成标准时间 =====")
    print("结果:", ISO格式转标准时间("2025-11-13T14:50:00+08:00"))

    print("\n===== 示例3：处理不带时区的 ISO 时间 =====")
    print("结果:", ISO格式转标准时间("2025-11-13T06:50:00"))

    print("\n===== 示例4：输入空字符串 =====")
    print("结果:", ISO格式转标准时间(""))

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", ISO格式转标准时间("2025/11/13 06:50:00"))

    print("\n===== 示例6：应用场景-整理接口返回的创建时间 =====")
    接口数据 = {
        "order_id": "ORD-1001",
        "created_at": "2025-11-13T06:50:00Z",
    }
    标准时间 = ISO格式转标准时间(接口数据["created_at"])
    print("订单创建时间:", 标准时间)



from typing import Any, Tuple


def 取字符串成员数量(元组数据: Tuple[Any, ...]):
    """返回元组中字符串成员的数量。

    功能说明:
        - 这个函数用于返回元组中字符串成员的数量。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。
"""
    try:
        if not isinstance(元组数据, tuple):
            return None
        return sum(1 for 元素 in 元组数据 if isinstance(元素, str))
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础字符串统计 =====")
    数据 = ("a", "b", 1, None)
    print("结果:", 取字符串成员数量(数据))

    print("\n===== 示例2：空字符串也计入字符串 =====")
    数据 = ("a", "", "c")
    print("结果:", 取字符串成员数量(数据))

    print("\n===== 示例3：没有字符串 =====")
    数据 = (1, 2, None)
    print("结果:", 取字符串成员数量(数据))

    print("\n===== 示例4：包含 bytes 不算字符串 =====")
    数据 = ("a", b"b", "c")
    print("结果:", 取字符串成员数量(数据))

    print("\n===== 示例5：空元组 =====")
    数据 = ()
    print("结果:", 取字符串成员数量(数据))

    print("\n===== 示例6：应用场景-统计文本字段数量 =====")
    字段列表 = ("张三", "13800000001", 18, "北京", None)
    print("结果:", 取字符串成员数量(字段列表))






from datetime import datetime


def 标准时间转中文时间(时间字符串: str) -> str | None:
    """把标准时间字符串转成中文时间字符串。

    功能说明:
        - 这个函数用于把 ``YYYY-MM-DD HH:MM:SS`` 转成 ``2026年3月20日10时30分45秒`` 这种中文格式。
        - 适合在面向用户的界面、通知文案和合同文本中展示时间。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: 标准时间字符串。

    Returns:
        成功时返回中文时间字符串；失败时返回 ``None``。
    """
    try:
        时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return (
            f"{时间对象.year}年{时间对象.month}月{时间对象.day}日"
            f"{时间对象.hour}时{时间对象.minute}分{时间对象.second}秒"
        )
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：标准时间转中文时间 =====")
    print("结果:", 标准时间转中文时间("2026-03-20 10:30:45"))

    print("\n===== 示例2：个位数时间转中文时间 =====")
    print("结果:", 标准时间转中文时间("2026-03-02 05:06:07"))

    print("\n===== 示例3：午夜时间转中文时间 =====")
    print("结果:", 标准时间转中文时间("2026-03-20 00:00:00"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 标准时间转中文时间("2026/03/20 10:30:45"))

    print("\n===== 示例5：输入空字符串 =====")
    print("结果:", 标准时间转中文时间(""))

    print("\n===== 示例6：应用场景-给通知消息显示中文时间 =====")
    print("结果:", 标准时间转中文时间("2026-03-20 18:00:00"))
